@@ -674,7 +674,7 @@ function calcDirSize($path)
 function convBytes($val)
 {
 	$val = trim($val);
-	$last = strtolower($val{strlen($val) -1});
+	$last = strtolower($val[strlen($val) -1]);
 	switch($last){
 		case 'g':
 			$val *= 1024;
