@@ -20,10 +20,8 @@ class Crawlers extends AbstractProvider
      */
     protected $data = array(
         '.*Java.*outbrain',
-        '008\/',
-        '192\.comAgent',
-        '2ip\.ru',
-        '404checker',
+        ' YLT',
+        '^b0t$',
         '^bluefish ',
         '^Calypso v\/',
         '^COMODO DCV',
@@ -32,10 +30,12 @@ class Crawlers extends AbstractProvider
         '^FDM ',
         '^git\/',
         '^Goose\/',
+        '^Grabber',
         '^HTTPClient\/',
         '^Java\/',
         '^Jeode\/',
         '^Jetty\/',
+        '^Mail\/',
         '^Mget',
         '^Microsoft URL Control',
         '^NG\/[0-9\.]',
@@ -43,219 +43,353 @@ class Crawlers extends AbstractProvider
         '^PHP\/[0-9]',
         '^RMA\/',
         '^Ruby|Ruby\/[0-9]',
-        '^scrutiny\/',
         '^VSE\/[0-9]',
         '^WordPress\.com',
         '^XRL\/[0-9]',
         '^ZmEu',
+        '008\/',
+        '13TABS',
+        '192\.comAgent',
+        '2ip\.ru',
+        '404enemy',
+        '7Siters',
+        '80legs',
+        'a\.pr-cy\.ru',
         'a3logics\.in',
         'A6-Indexer',
-        'a\.pr-cy\.ru',
+        'Abonti',
         'Aboundex',
         'aboutthedomain',
         'Accoona-AI-Agent',
         'acoon',
         'acrylicapps\.com\/pulp',
+        'Acunetix',
+        'AdAuth\/',
         'adbeat',
         'AddThis',
         'ADmantX',
+        'AdminLabs',
         'adressendeutschland',
-        'Advanced Email Extractor v',
+        'adscanner',
+        'Adstxtaggregator',
         'agentslug',
         'AHC',
         'aihit',
         'aiohttp\/',
         'Airmail',
+        'akka-http\/',
         'akula\/',
         'alertra',
         'alexa site audit',
         'Alibaba\.Security\.Heimdall',
+        'Alligator',
+        'allloadin',
+        'AllSubmitter',
         'alyze\.info',
         'amagit',
+        'Anarchie',
         'AndroidDownloadManager',
         'Anemone',
+        'AngleSharp',
+        'annotate_google',
         'Ant\.com',
         'Anturis Agent',
         'AnyEvent-HTTP\/',
-        'Apache-HttpClient\/',
-        'AportWorm\/[0-9]',
+        'Apache Droid',
+        'Apache OpenOffice',
+        'Apache-HttpAsyncClient',
+        'Apache-HttpClient',
+        'ApacheBench',
+        'Apexoo',
+        'APIs-Google',
+        'AportWorm\/',
+        'AppBeat\/',
         'AppEngine-Google',
+        'AppStoreScraperZ',
+        'Aprc\/[0-9]',
         'Arachmo',
         'arachnode',
         'Arachnophilia',
         'aria2',
-        'asafaweb.com',
+        'Arukereso',
+        'asafaweb',
         'AskQuickly',
+        'Ask Jeeves',
+        'ASPSeek',
+        'Asterias',
         'Astute',
         'asynchttp',
+        'Attach',
         'autocite',
         'Autonomy',
+        'axios\/',
         'B-l-i-t-z-B-O-T',
-        'Backlink-Ceck\.de',
+        'Backlink-Ceck',
+        'backlink-check',
+        'BacklinkHttpStatus',
+        'BackStreet',
+        'BackWeb',
         'Bad-Neighborhood',
+        'Badass',
         'baidu\.com',
-        'baypup\/[0-9]',
-        'baypup\/colbert',
+        'Bandit',
+        'basicstate',
+        'BatchFTP',
+        'Battleztar Bazinga',
+        'baypup\/',
         'BazQux',
+        'BBBike',
         'BCKLINKS',
         'BDFetch',
-        'BegunAdvertising\/',
+        'BegunAdvertising',
+        'Bidtellect',
         'BigBozz',
+        'Bigfoot',
         'biglotron',
         'BingLocalSearch',
         'BingPreview',
         'binlar',
         'biNu image cacher',
+        'Bitacle',
         'biz_Directory',
+        'Black Hole',
         'Blackboard Safeassign',
+        'BlackWidow',
+        'BlockNote\.Net',
+        'Bloglines',
         'Bloglovin',
         'BlogPulseLive',
         'BlogSearch',
         'Blogtrottr',
+        'BlowFish',
         'boitho\.com-dc',
         'BPImageWalker',
         'Braintree-Webhooks',
         'Branch Metrics API',
         'Branch-Passthrough',
+        'Brandprotect',
+        'BrandVerity',
+        'Brandwatch',
+        'Brodie\/',
         'Browsershots',
         'BUbiNG',
+        'Buck\/',
+        'Buddy',
+        'BuiltWith',
+        'Bullseye',
+        'BunnySlippers',
+        'Burf Search',
         'Butterfly\/',
         'BuzzSumo',
         'CAAM\/[0-9]',
         'CakePHP',
-        'CapsuleChecker',
+        'Calculon',
+        'Canary%20Mail',
         'CaretNail',
         'catexplorador',
-        'cb crawl',
         'CC Metadata Scaper',
+        'Cegbfeieh',
+        'censys',
         'Cerberian Drtrs',
         'CERT\.at-Statistics-Survey',
         'cg-eye',
         'changedetection',
+        'ChangesMeter',
         'Charlotte',
         'CheckHost',
         'checkprivacy',
+        'CherryPicker',
+        'ChinaClaw',
+        'Chirp\/',
         'chkme\.com',
-        'CirrusExplorer\/',
+        'Chlooe',
+        'Chromaxa',
+        'CirrusExplorer',
         'CISPA Vulnerability Notification',
+        'Citoid',
         'CJNetworkQuality',
+        'Clarsentia',
         'clips\.ua\.ac\.be',
-        'Cloud mapping experiment',
+        'Cloud mapping',
+        'CloudEndure',
         'CloudFlare-AlwaysOnline',
-        'Cloudinary\/[0-9]',
+        'Cloudinary',
         'cmcm\.com',
         'coccoc',
+        'cognitiveseo',
+        'colly -',
         'CommaFeed',
         'Commons-HttpClient',
-        'Comodo SSL Checker',
+        'commonscan',
         'contactbigdatafr',
+        'contentkingapp',
         'convera',
+        'CookieReports',
         'copyright sheriff',
+        'CopyRightCheck',
+        'Copyscape',
+        'Cosmos4j\.feedback',
         'Covario-IDS',
-        'CrawlForMe\/[0-9]',
-        'cron-job\.org',
+        'Crescent',
         'Crowsnest',
+        'Criteo',
+        'CSHttp',
         'curb',
         'Curious George',
         'curl',
-        'cuwhois\/[0-9]',
+        'cuwhois\/',
         'cybo\.com',
+        'DAP\/NetHTTP',
         'DareBoost',
+        'DatabaseDriverMysqli',
+        'DataCha0s',
+        'Datafeedwatch',
+        'Datanyze',
         'DataparkSearch',
         'dataprovider',
+        'DataXu',
         'Daum(oa)?[ \/][0-9]',
+        'Demon',
         'DeuSu',
         'developers\.google\.com\/\+\/web\/snippet\/',
+        'Devil',
         'Digg',
+        'Digincore',
+        'DigitalPebble',
+        'Dirbuster',
+        'Discourse Forum Onebox',
+        'Disqus\/',
         'Dispatch\/',
+        'DittoSpyder',
         'dlvr',
-        'DMBrowser-UV',
-        'DNS-Tools Header-Analyzer',
+        'DMBrowser',
         'DNSPod-reporting',
         'docoloc',
-        'Dolphin http client\/',
+        'Dolphin http client',
         'DomainAppender',
+        'Donuts Content Explorer',
+        'dotMailer content retrieval',
         'dotSemantic',
         'downforeveryoneorjustme',
-        'downnotifier\.com',
+        'Download Wonder',
+        'downnotifier',
         'DowntimeDetector',
-        'Dragonfly File Reader',
+        'Drip',
         'drupact',
         'Drupal \(\+http:\/\/drupal\.org\/\)',
+        'DTS Agent',
         'dubaiindex',
         'EARTHCOM',
         'Easy-Thumb',
+        'EasyDL',
+        'Ebingbong',
         'ec2linkfinder',
         'eCairn-Grabber',
+        'eCatch',
         'ECCP',
+        'eContext\/',
+        'Ecxi',
+        'EirGrabber',
         'ElectricMonk',
         'elefent',
         'EMail Exractor',
+        'EMail Wolf',
         'EmailWolf',
+        'Embarcadero',
         'Embed PHP Library',
         'Embedly',
+        'endo\/',
         'europarchive\.org',
-        'evc-batch\/[0-9]',
+        'evc-batch',
         'EventMachine HttpClient',
+        'Everwall Link Expander',
         'Evidon',
         'Evrinid',
         'ExactSearch',
         'ExaleadCloudview',
         'Excel\/',
-        'Exif Viewer',
+        'exif',
         'Exploratodo',
+        'Express WebPictures',
+        'Extreme Picture Finder',
+        'EyeNetIE',
         'ezooms',
         'facebookexternalhit',
         'facebookplatform',
         'fairshare',
         'Faraday v',
+        'fasthttp',
         'Faveeo',
         'Favicon downloader',
+        'faviconkit',
+        'faviconarchive',
         'FavOrg',
         'Feed Wrangler',
+        'Feedable\/',
         'Feedbin',
         'FeedBooster',
         'FeedBucket',
-        'FeedBunch\/[0-9]',
+        'FeedBunch\/',
         'FeedBurner',
-        'FeedChecker',
+        'feeder',
         'Feedly',
+        'FeedshowOnline',
         'Feedspot',
-        'Feedwind\/[0-9]',
+        'Feedwind\/',
+        'FeedZcollector',
         'feeltiptop',
         'Fetch API',
         'Fetch\/[0-9]',
         'Fever\/[0-9]',
+        'FHscan',
+        'Fimap',
         'findlink',
         'findthatfile',
+        'FlashGet',
         'FlipboardBrowserProxy',
         'FlipboardProxy',
         'FlipboardRSS',
+        'Flock\/',
         'fluffy',
+        'Flunky',
         'flynxapp',
         'forensiq',
-        'FoundSeoTool\/[0-9]',
+        'FoundSeoTool',
+        'http:\/\/www.neomo.de\/', //'Francis [Bot]'
         'free thumbnails',
-        'FreeWebMonitoring SiteChecker',
+        'Freeuploader',
         'Funnelback',
+        'G-i-g-a-b-o-t',
         'g00g1e\.net',
-        'GAChecker',
-        'ganarvisitas\/[0-9]',
+        'ganarvisitas',
         'geek-tools',
-        'Genderanalyzer',
         'Genieo',
         'GentleSource',
+        'GetCode',
+        'Getintent',
         'GetLinkInfo',
-        'getprismatic\.com',
-        'GetURLInfo\/[0-9]',
+        'getprismatic',
+        'GetRight',
+        'getroot',
+        'GetURLInfo\/',
+        'GetWeb',
+        'Ghost Inspector',
         'GigablastOpenSource',
-        'github\.com\/',
+        'GIS-LABS',
+        'github-camo',
+        'github\.com',
         'Go [\d\.]* package http',
+        'Go http package',
+        'Go-Ahead-Got-It',
         'Go-http-client',
+        'Go!Zilla',
+        'gobyus',
         'gofetch',
         'GomezAgent',
         'gooblog',
-        'Goodzer\/[0-9]',
+        'Goodzer\/',
+        'Google AppsViewer',
+        'Google Desktop',
         'Google favicon',
         'Google Keyword Suggestion',
         'Google Keyword Tool',
@@ -266,121 +400,193 @@ class Crawlers extends AbstractProvider
         'Google-Adwords',
         'Google-Apps-Script',
         'Google-Calendar-Importer',
+        'Google-HotelAdsVerifier',
         'Google-HTTP-Java-Client',
         'Google-Publisher-Plugin',
         'Google-SearchByImage',
         'Google-Site-Verification',
         'Google-Structured-Data-Testing-Tool',
         'Google-Youtube-Links',
-        'google_partner_monitoring',
+        'google-xrawler',
         'GoogleDocs',
         'GoogleHC\/',
         'GoogleProducer',
+        'GoogleSites',
+        'Google-Transparency-Report',
+        'Gookey',
         'GoScraper',
         'GoSpotCheck',
-        'GoSquared-Status-Checker',
         'gosquared-thumbnailer',
-        'GotSiteMonitor',
+        'Gotit',
+        'GoZilla',
         'grabify',
+        'GrabNet',
+        'Grafula',
         'Grammarly',
+        'GrapeFX',
+        'GreatNews',
+        'Gregarius',
+        'GRequests',
+        'grokkit',
         'grouphigh',
         'grub-client',
+        'gSOAP\/',
+        'GT::WWW',
         'GTmetrix',
+        'GuzzleHttp',
         'gvfs\/',
         'HAA(A)?RTLAND http client',
+        'Haansoft',
+        'hackney\/',
+        'Hadi Agent',
+        'HappyApps-WebCheck',
         'Hatena',
-        'hawkReader',
+        'Havij',
+        'HeadlessChrome',
         'HEADMasterSEO',
         'HeartRails_Capture',
+        'help@dataminr\.com',
         'heritrix',
-        'hledejLevne\.cz\/[0-9]',
+        'historious',
+        'hkedcity',
+        'hledejLevne\.cz',
+        'Hloader',
+        'HMView',
         'Holmes',
+        'HonesoSearchEngine',
         'HootSuite Image proxy',
-        'Hootsuite-WebFeed\/[0-9]',
+        'Hootsuite-WebFeed',
+        'hosterstats',
         'HostTracker',
         'ht:\/\/check',
         'htdig',
-        'HTMLParser\/',
-        'HTTP-Header-Abfrage',
-        'http-kit',
-        'HTTP-Tiny',
+        'HTMLparser',
+        'htmlyse',
+        'HTTP Banner Detection',
         'HTTP_Compression_Test',
         'http_request2',
         'http_requester',
+        'http-get',
+        'HTTP-Header-Abfrage',
+        'http-kit',
+        'http-request\/',
+        'HTTP-Tiny',
+        'HTTP::Lite',
+        'http\.rb\/',
+        'http_get',
         'HttpComponents',
         'httphr',
         'HTTPMon',
-        'PEAR HTTPRequest',
+        'httpRequest',
         'httpscheck',
         'httpssites_power',
         'httpunit',
         'HttpUrlConnection',
         'httrack',
-        'hosterstats',
         'huaweisymantec',
-        'HubPages.*crawlingpolicy',
-        'HubSpot Connect',
-        'HubSpot Marketing Grader',
-        'HyperZbozi.cz Feeder',
+        'HubSpot ',
+        'Humanlinks',
         'i2kconnect\/',
+        'Iblog',
         'ichiro',
+        'Id-search',
         'IdeelaborPlagiaat',
         'IDG Twitter Links Resolver',
-        'IDwhois\/[0-9]',
+        'IDwhois\/',
         'Iframely',
         'igdeSpyder',
         'IlTrovatore',
+        'Image Fetch',
+        'Image Sucker',
         'ImageEngine\/',
+        'ImageVisu\/',
         'Imagga',
+        'imagineeasy',
+        'imgsizer',
         'InAGist',
         'inbound\.li parser',
         'InDesign%20CC',
+        'Indy Library',
+        'InetURL',
         'infegy',
         'infohelfer',
-        'InfoWizards Reciprocal Link System PRO',
-        'Instapaper',
+        'InfoTekies',
+        'InfoWizards Reciprocal Link',
         'inpwrd\.com',
+        'instabid',
+        'Instapaper',
         'Integrity',
         'integromedb',
+        'Intelliseek',
+        'InterGET',
         'internet_archive',
+        'Internet Ninja',
         'InternetSeer',
         'internetVista monitor',
+        'intraVnews',
         'IODC',
         'IOI',
         'iplabel',
-        'IPS\/[0-9]',
         'ips-agent',
+        'IPS\/[0-9]',
         'IPWorks HTTP\/S Component',
         'iqdb\/',
+        'Iria',
         'Irokez',
         'isitup\.org',
         'iskanie',
+        'isUp\.li',
+        'iThemes Sync\/',
         'iZSearch',
+        'JAHHO',
         'janforman',
+        'Jaunt\/',
+        'Jbrofuzz',
+        'Jersey\/',
+        'JetCar',
         'Jigsaw',
         'Jobboerse',
+        'JobFeed discovery',
+        'Jobg8 URL Monitor',
         'jobo',
         'Jobrapido',
+        'Jobsearch1\.5',
+        'JoinVision Generic',
+        'JolokiaPwn',
+        'Joomla',
+        'Jorgee',
         'JS-Kit',
-        'KeepRight OpenStreetMap Checker',
-        'KeyCDN Perf Test',
+        'JustView',
+        'Kaspersky Lab CFR link resolver',
+        'Kelny\/',
+        'Kerrigan\/',
+        'KeyCDN',
+        'Keyword Density',
         'Keywords Research',
         'KickFire',
         'KimonoLabs\/',
         'Kml-Google',
         'knows\.is',
+        'KOCMOHABT',
         'kouio',
-        'KrOWLer',
+        'kube-probe',
         'kulturarw3',
         'KumKie',
         'L\.webis',
         'Larbin',
-        'LayeredExtractor',
+        'Lavf\/',
+        'LeechFTP',
+        'LeechGet',
+        'letsencrypt',
+        'Lftp',
         'LibVLC',
+        'LibWeb',
+        'Libwhisker',
         'libwww',
-        'Licorne Image Snapshot',
+        'Licorne',
         'Liferea\/',
-        'link checker',
+        'Lightspeedsystems',
+        'Likse',
         'Link Valet',
         'link_thumbnailer',
         'LinkAlarm\/',
@@ -389,75 +595,130 @@ class Crawlers extends AbstractProvider
         'LinkExaminer',
         'linkfluence',
         'linkpeek',
+        'LinkPreviewGenerator',
+        'LinkScan',
+        'LinksManager',
         'LinkTiger',
         'LinkWalker',
         'Lipperhey',
+        'Litemage_walker',
         'livedoor ScreenShot',
-        'LoadImpactPageAnalyzer',
         'LoadImpactRload',
+        'localsearch-web',
         'LongURL API',
         'looksystems\.net',
         'ltx71',
+        'lua-resty-http',
+        'lwp-request',
         'lwp-trivial',
+        'LWP::Simple',
         'lycos',
         'LYT\.SR',
         'mabontland',
+        'Mag-Net',
         'MagpieRSS',
-        'Mail.Ru',
-        'MailChimp\.com',
+        'Mail\.Ru',
+        'MailChimp',
+        'Majestic12',
+        'makecontact\/',
         'Mandrill',
         'MapperCmd',
         'marketinggrader',
+        'MarkMonitor',
+        'MarkWatch',
+        'Mass Downloader',
+        'masscan\/',
+        'Mata Hari',
         'Mediapartners-Google',
+        'mediawords',
         'MegaIndex\.ru',
-        'Melvil Rawi\/',
-        'MergeFlow-PageReader',
+        'MeltwaterNews',
+        'Melvil Rawi',
+        'MemGator',
         'Metaspinner',
         'MetaURI',
+        'MFC_Tear_Sample',
         'Microsearch',
-        'Microsoft-WebDAV-MiniRedir',
-        'Microsoft Data Access Internet Publishing Provider Protocol',
         'Microsoft Office ',
+        'Microsoft Outlook',
         'Microsoft Windows Network Diagnostics',
+        'Microsoft-WebDAV-MiniRedir',
+        'Microsoft Data Access',
+        'MIDown tool',
+        'MIIxpc',
         'Mindjet',
+        'Miniature\.io',
         'Miniflux',
+        'Mister PiX',
         'mixdata dot com',
         'mixed-content-scan',
+        'Mixmax-LinkPreview',
+        'mixnode',
         'Mnogosearch',
         'mogimogi',
+        'Mojeek',
         'Mojolicious \(Perl\)',
+        'Monit\/',
         'monitis',
-        'Monitority\/[0-9]',
+        'Monitority\/',
         'montastic',
         'MonTools',
         'Moreover',
+        'Morfeus Fucking Scanner',
         'Morning Paper',
+        'MovableType',
         'mowser',
         'Mrcgiguy',
+        'MS Web Services Client Protocol',
+        'MSFrontPage',
         'mShots',
+        'MuckRack\/',
+        'muhstik-scan',
         'MVAClient',
+        'MxToolbox\/',
         'nagios',
-        'Najdi\.si\/',
-        'Needle\/',
+        'Najdi\.si',
+        'Name Intelligence',
+        'Nameprotect',
+        'Navroad',
+        'NearSite',
+        'Needle',
+        'Nessus',
+        'Net Vampire',
+        'NetAnts',
         'NETCRAFT',
-        'NetLyzer FastProbe',
+        'NetLyzer',
+        'NetMechanic',
+        'NetNewsWire',
+        'Netpursual',
         'netresearch',
         'NetShelter ContentScan',
+        'Netsparker',
         'NetTrack',
         'Netvibes',
+        'NetZIP',
         'Neustar WPM',
         'NeutrinoAPI',
+        'NewRelicPinger',
         'NewsBlur .*Finder',
         'NewsGator',
         'newsme',
         'newspaper\/',
+        'Nexgate Ruby Client',
         'NG-Search',
-        'nineconnections\.com',
+        'Nibbler',
+        'NICErsPRO',
+        'Nikto',
+        'nineconnections',
         'NLNZ_IAHarvester',
         'Nmap Scripting Engine',
         'node-superagent',
+        'node-urllib',
         'node\.io',
+        'Nodemeter',
+        'NodePing',
         'nominet\.org\.uk',
+        'nominet\.uk',
         'Norton-Safeweb',
         'Notifixious',
         'notifyninja',
@@ -465,157 +726,252 @@ class Crawlers extends AbstractProvider
         'nutch',
         'Nuzzel',
         'nWormFeedFinder',
+        'nyawc\/',
         'Nymesis',
-        'Ocelli\/[0-9]',
+        'NYU',
+        'Ocelli\/',
+        'Octopus',
         'oegp',
+        'Offline Explorer',
+        'Offline Navigator',
+        'og-scraper',
         'okhttp',
-        'Omea Reader',
         'omgili',
+        'OMSC',
         'Online Domain Tools',
         'OpenCalaisSemanticProxy',
+        'Openfind',
+        'OpenLinkProfiler',
         'Openstat\/',
         'OpenVAS',
         'Optimizer',
         'Orbiter',
-        'OrgProbe\/[0-9]',
+        'OrgProbe\/',
+        'orion-semantics',
+        'Outlook-Express',
+        'Outlook-iOS',
         'ow\.ly',
+        'Owler',
         'ownCloud News',
-        'OxfordCloudService\/[0-9]',
-        'Page Analyzer',
+        'OxfordCloudService',
         'Page Valet',
-        'page2rss',
         'page_verifier',
+        'page scorer',
+        'page2rss',
+        'PageGrabber',
         'PagePeeker',
-        'Pagespeed\/[0-9]',
+        'PageScorer',
+        'Pagespeed\/',
         'Panopta',
         'panscient',
+        'Papa Foto',
         'parsijoo',
+        'Pavuk',
         'PayPal IPN',
+        'pcBrowser',
         'Pcore-HTTP',
         'Pearltrees',
+        'PECL::HTTP',
         'peerindex',
         'Peew',
+        'PeoplePal',
+        'Perlu -',
+        'PhantomJS Screenshoter',
         'PhantomJS\/',
         'Photon\/',
-        'phpcrawl',
         'phpservermon',
         'Pi-Monster',
-        'ping\.blo\.gs\/',
+        'Picscout',
+        'Picsearch',
+        'PictureFinder',
+        'Pimonster',
+        'ping\.blo\.gs',
+        'Pingability',
+        'PingAdmin\.Ru',
         'Pingdom',
         'Pingoscope',
         'PingSpot',
         'pinterest\.com',
+        'Pixray',
         'Pizilla',
+        'Plagger\/',
         'Ploetz \+ Zeller',
         'Plukkie',
+        'plumanalytics',
+        'PocketImageCache',
         'PocketParser',
+        'Pockey',
+        'POE-Component-Client-HTTP',
+        'Polymail\/',
         'Pompos',
         'Porkbun',
         'Port Monitor',
         'postano',
+        'PostmanRuntime',
         'PostPost',
         'postrank',
         'PowerPoint\/',
         'Priceonomics Analysis Engine',
-        'PritTorrent\/[0-9]',
+        'PrintFriendly',
+        'PritTorrent',
         'Prlog',
         'probethenet',
         'Project 25499',
-        'Promotion_Tools_www.searchenginepromotionhelp.com',
         'prospectb2b',
         'Protopage',
+        'ProWebWalker',
         'proximic',
+        'PRTG Network Monitor',
         'pshtt, https scanning',
         'PTST ',
         'PTST\/[0-9]+',
         'Pulsepoint XT3 web scraper',
+        'Pump',
         'Python-httplib2',
         'python-requests',
         'Python-urllib',
         'Qirina Hurdler',
         'QQDownload',
+        'QrafterPro',
         'Qseero',
-        'Qualidator.com SiteAnalyzer',
+        'Qualidator',
+        'QueryN Metasearch',
+        'queuedriver',
         'Quora Link Preview',
         'Qwantify',
         'Radian6',
+        'RankActive',
+        'RankFlex',
         'RankSonicSiteAuditor',
+        'Re-re Studio',
+        'ReactorNetty',
         'Readability',
+        'RealDownload',
         'RealPlayer%20Downloader',
         'RebelMouse',
+        'Recorder',
+        'RecurPost\/',
         'redback\/',
-        'Redirect Checker Tool',
         'ReederForMac',
+        'ReGet',
+        'RepoMonkey',
         'request\.js',
-        'ResponseCodeTest\/[0-9]',
+        'reqwest\/',
+        'ResponseCodeTest',
         'RestSharp',
-        'RetrevoPageAnalyzer',
         'Riddler',
         'Rival IQ',
         'Robosourcer',
-        'Robozilla\/[0-9]',
+        'Robozilla',
         'ROI Hunter',
         'RPT-HTTPClient',
         'RSSOwl',
         'safe-agent-scanner',
         'SalesIntelligent',
+        'Saleslift',
+        'Sendsay\.Ru',
         'SauceNAO',
         'SBIder',
+        'scalaj-http',
+        'scan\.lol',
+        'ScanAlert',
         'Scoop',
         'scooter',
         'ScoutJet',
         'ScoutURLMonitor',
+        'ScrapeBox Page Scanner',
+        'SimpleScraper',
         'Scrapy',
-        'ScreenShotService\/[0-9]',
+        'Screaming',
+        'ScreenShotService',
         'Scrubby',
+        'Scrutiny\/',
         'search\.thunderstone',
+        'Search37',
+        'searchenginepromotionhelp',
+        'Searchestate',
+        'SearchExpress',
         'SearchSight',
         'Seeker',
         'semanticdiscovery',
         'semanticjuice',
         'Semiocast HTTP client',
+        'Semrush',
+        'sentry\/',
         'SEO Browser',
         'Seo Servis',
-        'seo-nastroj.cz',
+        'seo-nastroj\.cz',
+        'seo4ajax',
         'Seobility',
         'SEOCentro',
         'SeoCheck',
-        'SeopultContentAnalyzer',
-        'Server Density Service Monitoring',
-        'servernfo\.com',
-        'Seznam screenshot-generator',
+        'SEOkicks',
+        'Seomoz',
+        'SEOprofiler',
+        'SEOsearch',
+        'seoscanners',
+        'seositecheckup',
+        'SEOstats',
+        'servernfo',
+        'sexsearcher',
+        'Seznam',
         'Shelob',
-        'Shoppimon Analyzer',
-        'ShoppimonAgent\/[0-9]',
+        'Shodan',
+        'Shoppimon',
         'ShopWiki',
         'ShortLinkTranslate',
         'shrinktheweb',
-        'SilverReader',
+        'Sideqik',
         'SimplePie',
         'SimplyFast',
+        'Siphon',
+        'SISTRIX',
         'Site-Shot\/',
+        'Site Sucker',
         'Site24x7',
         'SiteBar',
+        'Sitebeam',
+        'Sitebulb\/',
         'SiteCondor',
-        'siteexplorer\.info',
+        'SiteExplorer',
         'SiteGuardian',
-        'Siteimprove\.com',
+        'Siteimprove',
+        'SiteIndexed',
         'Sitemap(s)? Generator',
+        'SitemapGenerator',
+        'SiteMonitor',
         'Siteshooter B0t',
+        'SiteSnagger',
+        'SiteSucker',
         'SiteTruth',
+        'Sitevigil',
         'sitexy\.com',
         'SkypeUriPreview',
+        'Slack\/',
         'slider\.com',
         'slurp',
+        'SlySearch',
+        'SmartDownload',
         'SMRF URL Expander',
         'SMUrlExpander',
+        'Snake',
         'Snappy',
+        'SnapSearch',
+        'Snarfer\/',
         'SniffRSS',
         'sniptracker',
         'Snoopy',
+        'SnowHaze Search',
         'sogou web',
         'SortSite',
+        'Sottopop',
+        'sovereign\.ai',
+        'SpaceBison',
+        'SpamExperts',
+        'Spammen',
+        'Spanner',
         'spaziodati',
+        'SPDYCheck',
         'Specificfeeds',
         'speedy',
         'SPEng',
@@ -623,155 +979,260 @@ class Crawlers extends AbstractProvider
         'spray-can',
         'Sprinklr ',
         'spyonweb',
+        'sqlmap',
+        'Sqlworm',
         'Sqworm',
         'SSL Labs',
+        'ssl-tools',
         'StackRambler',
         'Statastico\/',
         'StatusCake',
+        'Steeler',
         'Stratagems Kumo',
-        'Stroke.cz',
+        'Stroke\.cz',
         'StudioFACA',
+        'StumbleUpon',
         'suchen',
+        'Sucuri',
         'summify',
-        'Super Monitoring',
+        'SuperHTTP',
         'Surphace Scout',
+        'Suzuran',
         'SwiteScraper',
+        'Symfony BrowserKit',
         'Symfony2 BrowserKit',
         'SynHttpClient-Built',
         'Sysomos',
+        'sysscan',
+        'Szukacz',
         'T0PHackTeam',
+        'tAkeOut',
         'Tarantula\/',
         'Taringa UGC',
+        'TarmotGezgin',
+        'Teleport',
+        'Telesoft',
+        'Telesphoreo',
+        'Telesphorep',
+        'Tenon\.io',
         'teoma',
-        'terrainformatica\.com',
+        'terrainformatica',
         'Test Certificate Info',
-        'Tetrahedron\/[0-9]',
+        'testuri',
+        'Tetrahedron',
         'The Drop Reaper',
         'The Expert HTML Source Viewer',
+        'The Knowledge AI',
+        'The Intraformant',
         'theinternetrules',
-        'theoldreader\.com',
+        'TheNomad',
+        'Thinklab',
         'Thumbshots',
         'ThumbSniper',
+        'timewe\.net',
         'TinEye',
         'Tiny Tiny RSS',
+        'TLSProbe\/',
+        'Toata',
         'topster',
-        'touche.com',
-        'Traackr.com',
+        'touche\.com',
+        'Traackr\.com',
+        'tracemyfile',
+        'TrapitAgent',
+        'Trendiction',
+        'Trendsmap',
+        'trendspottr',
         'truwoGPS',
-        'tweetedtimes\.com',
+        'TryJsoup',
+        'TulipChain',
+        'Turingos',
+        'Turnitin',
+        'tweetedtimes',
         'Tweetminster',
         'Tweezler\/',
+        'twibble',
+        'Twice',
         'Twikle',
         'Twingly',
+        'Twisted PageGetter',
+        'Typhoeus',
         'ubermetrics-technologies',
         'uclassify',
         'UdmSearch',
+        'unchaos',
+        'unirest-java',
+        'UniversalFeedParser',
+        'Unshorten\.It',
         'Untiny',
         'UnwindFetchor',
         'updated',
+        'updown\.io daemon',
         'Upflow',
-        'URLChecker',
-        'URLitor.com',
+        'Uptimia',
+        'Urlcheckr',
+        'URL Verifier',
+        'URLitor',
         'urlresolver',
         'Urlstat',
+        'URLTester',
         'UrlTrends Ranking Updater',
+        'URLy Warning',
+        'URLy\.Warning',
+        'Vacuum',
         'Vagabondo',
+        'VB Project',
         'vBSEO',
+        'VCI',
         'via ggpht\.com GoogleImageProxy',
-        'VidibleScraper\/',
+        'VidibleScraper',
+        'Virusdie',
         'visionutils',
         'vkShare',
+        'VoidEYE',
+        'Voil',
         'voltron',
         'voyager\/',
-        'VSAgent\/[0-9]',
-        'VSB-TUO\/[0-9]',
+        'VSAgent\/',
+        'VSB-TUO\/',
+        'Vulnbusters Meter',
         'VYU2',
         'w3af\.org',
+        'W3C_Unicorn',
         'W3C-checklink',
         'W3C-mobileOK',
-        'W3C_I18n-Checker',
-        'W3C_Unicorn',
+        'WAC-OFU',
+        'Wallpapers\/[0-9]+',
+        'WallpapersHD',
         'wangling',
+        'Wappalyzer',
         'WatchMouse',
         'WbSrch\/',
+        'WDT\.io',
         'web-capture\.net',
-        'Web-Monitoring',
         'Web-sniffer',
+        'Web Auto',
+        'Web Collage',
+        'Web Enhancer',
+        'Web Fetch',
+        'Web Fuck',
+        'Web Pix',
+        'Web Sauger',
+        'Web Sucker',
+        'Webalta',
         'Webauskunft',
+        'WebAuto',
         'WebCapture',
         'WebClient\/',
         'webcollage',
         'WebCookies',
+        'WebCopier',
         'WebCorp',
+        'WebDataStats',
         'WebDoc',
+        'WebEnhancer',
         'WebFetch',
+        'WebFuck',
+        'WebGazer',
+        'WebGo IS',
+        'WebImageCollector',
         'WebImages',
         'WebIndex',
         'webkit2png',
+        'WebLeacher',
         'webmastercoffee',
         'webmon ',
+        'WebPix',
+        'WebReaper',
+        'WebSauger',
         'webscreenie',
+        'Webshag',
         'Webshot',
-        'Website Analyzer\/',
-        'websitepulse[+ ]checker',
-        'Websnapr\/',
-        'Webthumb\/[0-9]',
+        'Website Quester',
+        'websitepulse agent',
+        'WebsiteQuester',
+        'Websnapr',
+        'WebSniffer',
+        'Webster',
+        'WebStripper',
+        'WebSucker',
+        'Webthumb\/',
         'WebThumbnail',
-        'WeCrawlForThePeace',
+        'WebWhacker',
+        'WebZIP',
         'WeLikeLinks',
         'WEPA',
         'WeSEE',
         'wf84',
+        'Wfuzz\/',
         'wget',
         'WhatsApp',
         'WhatsMyIP',
         'WhatWeb',
         'WhereGoes\?',
         'Whibse',
+        'WhoRunsCoinHive',
         'Whynder Magnet',
         'Windows-RSS-Platform',
-        'WinHttpRequest',
+        'WinPodder',
         'wkhtmlto',
         'wmtips',
         'Woko',
+        'woorankreview',
         'Word\/',
         'WordPress\/',
+        'WordupinfoSearch',
         'wotbox',
         'WP Engine Install Performance API',
+        'wpif',
         'wprecon\.com survey',
         'WPScan',
         'wscheck',
+        'Wtrace',
+        'WWW-Collector-E',
         'WWW-Mechanize',
+        'WWW::Document',
+        'WWW::Mechanize',
         'www\.monitor\.us',
+        'WWWOFFLE',
+        'x09Mozilla',
+        'x22Mozilla',
         'XaxisSemanticsClassifier',
         'Xenu Link Sleuth',
-        'XING-contenttabreceiver\/[0-9]',
-        'XmlSitemapGenerator',
+        'XING-contenttabreceiver',
         'xpymep([0-9]?)\.exe',
         'Y!J-(ASR|BSC)',
+        'Y\!J-BRW',
         'Yaanb',
         'yacy',
-        'Yahoo Ad monitoring',
         'Yahoo Link Preview',
         'YahooCacheSystem',
         'YahooYSMcm',
         'YandeG',
-        'yandex',
+        'Yandex(?!Search)',
         'yanga',
         'yeti',
-        ' YLT',
         'Yo-yo',
         'Yoleo Consumer',
         'yoogliFetchAgent',
         'YottaaMonitor',
+        'Your-Website-Sucks',
         'yourls\.org',
+        'YoYs\.net',
+        'YP\.PL',
+        'Zabbix',
+        'Zade',
         'Zao',
+        'Zauba',
         'Zemanta Aggregator',
-        'Zend\\\\Http\\\\Client',
         'Zend_Http_Client',
+        'Zend\\\\Http\\\\Client',
+        'Zermelo',
+        'Zeus',
         'zgrab',
         'ZnajdzFoto',
+        'Zombie\.js',
+        'Zoom\.Mac',
         'ZyBorg',
-        '[a-z0-9\-_]*((?<!cu)bot|crawler|archiver|transcoder|spider|uptime|validator|fetcher)',
+        '[a-z0-9\-_]*(bot|crawl|archiver|transcoder|spider|uptime|validator|fetcher|cron|checker|reader|extractor|monitoring|analyzer)',
     );
 }
