@@ -90,6 +90,7 @@ CREATE TABLE _operation_log (
     ol_widget_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 実行ウィジェットID(ファイル名)
     ol_method            TEXT                                         NOT NULL,      -- 実行メソッド
     ol_access_log_serial INT            DEFAULT 0                     NOT NULL,      -- アクセスログシリアル番号
+	ol_user_id           INT            DEFAULT 0                     NOT NULL,      -- 記録ユーザID(0=不明)
     ol_dt                TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 記録日時
     PRIMARY KEY          (ol_serial)
 ) ENGINE=innodb;
@@ -168,15 +169,6 @@ CREATE TABLE _session (
     PRIMARY KEY  (ss_id)
 ) ENGINE=innodb;
 
--- 管理者一時キートラン
-DROP TABLE IF EXISTS _admin_key;
-CREATE TABLE _admin_key (
-    ak_id                CHAR(32)       DEFAULT ''                    NOT NULL,      -- ID
-    ak_ip                VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アクセス元IP(IPv6対応)
-    ak_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
-    PRIMARY KEY  (ak_id)
-) ENGINE=innodb;
-
 -- クライアント設定値
 DROP TABLE IF EXISTS _client_param;
 CREATE TABLE _client_param (
@@ -274,6 +266,17 @@ CREATE TABLE _login_user_info (
     UNIQUE               (li_id,        li_history_index)
 ) ENGINE=innodb;
 
+-- 個人最適化パラメータトラン
+DROP TABLE IF EXISTS _personalize_param;
+CREATE TABLE _personalize_param (
+    pz_id                CHAR(32)       DEFAULT ''                    NOT NULL,      -- クライアントID
+    
+    pz_param             TEXT                                         NOT NULL,      -- パラメータオブジェクトをシリアライズしたもの
+    pz_update_ip         VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- レコード更新アクセス元IP(IPv6対応)
+    pz_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    PRIMARY KEY          (pz_id)
+) ENGINE=innodb;
+
 -- 自動ログインマスター
 DROP TABLE IF EXISTS _auto_login;
 CREATE TABLE _auto_login (
@@ -337,16 +340,6 @@ CREATE TABLE _login_log (
     PRIMARY KEY  (ll_user_id)
 ) ENGINE=innodb;
 
--- ユーザログインエラートラン(廃止予定)
-DROP TABLE IF EXISTS _login_err_log;
-CREATE TABLE _login_err_log (
-    le_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
-    le_account           VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ログインアカウント
-    le_ip                VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アクセス元IP(IPv6対応)
-    le_access_log_serial INT            DEFAULT 0                     NOT NULL,      -- アクセスログシリアル番号
-    PRIMARY KEY          (le_serial)
-) ENGINE=innodb;
-
 -- ユーザアクセスログトラン
 DROP TABLE IF EXISTS _access_log;
 CREATE TABLE _access_log (
@@ -363,6 +356,7 @@ CREATE TABLE _access_log (
     al_user_agent        TEXT                                         NOT NULL,      -- アクセスプログラム
     al_accept_language   VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- クライアントの認識可能言語
     al_path              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アクセスポイントパス
+	al_landing_page_id   VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ランディングページID
     al_is_cmd            BOOLEAN        DEFAULT false                 NOT NULL,      -- コマンド実行かどうか
     al_cookie            BOOLEAN        DEFAULT false                 NOT NULL,      -- クッキーがあるかどうか
     al_crawler           BOOLEAN        DEFAULT false                 NOT NULL,      -- クローラかどうか
@@ -427,6 +421,21 @@ CREATE TABLE _access_ip (
     UNIQUE               (ai_type, ai_ip, ai_ip_mask, ai_server_id)
 ) ENGINE=innodb;
 
+-- セッションアクセスキー管理マスター
+DROP TABLE IF EXISTS _session_access_key;
+CREATE TABLE _session_access_key (
+    sk_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    sk_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- アクセスキー
+    sk_widget_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ウィジェットID
+	sk_content_id        VARCHAR(191)   DEFAULT ''                    NOT NULL,      -- コンテンツ識別用のID。コンテンツがない場合はウィジェット定義ID。
+
+    sk_type              SMALLINT       DEFAULT 0                     NOT NULL,      -- アクセスキータイプ(0=参照,1=発行)
+    sk_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    sk_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    PRIMARY KEY          (sk_serial),
+    UNIQUE               (sk_id, sk_widget_id, sk_content_id)
+) ENGINE=innodb;
+
 -- ナビゲーション項目マスター
 DROP TABLE IF EXISTS _nav_item;
 CREATE TABLE _nav_item (
@@ -444,6 +453,7 @@ CREATE TABLE _nav_item (
     ni_help_body         TEXT                                         NOT NULL,      -- ヘルプ本文
     ni_url               TEXT                                         NOT NULL,      -- リンク先URL
     ni_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示するかどうか
+    ni_hide_option       TEXT                                         NOT NULL,      -- 非表示制御オプション(「,」区切りで指定。値=site_operation(サイト運用モード時))
     PRIMARY KEY          (ni_nav_id,    ni_id)
 ) ENGINE=innodb;
 
@@ -538,7 +548,7 @@ CREATE TABLE _templates (
     tm_id                VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- テンプレートID
     tm_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
     
-    tm_type              INT            DEFAULT 0                     NOT NULL,      -- テンプレート種別(99=レイアウト用テンプレート,0=デフォルトテンプレート(Joomla!v1.0),1=Joomla!v1.5,2=Joomla!v2.5,10=Bootstrap v3.0,11=Bootstrap v4.0,20=jQuery Mobile,100=WordPress)
+    tm_type              INT            DEFAULT 0                     NOT NULL,      -- テンプレート種別(99=レイアウト用テンプレート,0=デフォルトテンプレート(Joomla!v1.0),1=Joomla!v1.5,2=Joomla!v2.5,10=Bootstrap v3.0,11=Bootstrap v4.0,100=WordPress)
     tm_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)
     tm_language          TEXT                                         NOT NULL,      -- 対応言語ID(「,」区切りで複数指定可)
     tm_generator         VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- テンプレート作成アプリケーション(値=artisteer,themler)
@@ -546,12 +556,15 @@ CREATE TABLE _templates (
     tm_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- テンプレート名
     tm_description       VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 説明
     tm_url               TEXT                                         NOT NULL,      -- 取得先URL
-	tm_info_url          TEXT                                         NOT NULL,      -- テンプレート情報URL
-	tm_custom_params     TEXT                                         NOT NULL,      -- カスタマイズ用パラメータ
+    tm_info_url          TEXT                                         NOT NULL,      -- テンプレート情報URL
+    tm_custom_params     TEXT                                         NOT NULL,      -- カスタマイズ用パラメータ
     tm_joomla_params     TEXT                                         NOT NULL,      -- joomla!用パラメータ(廃止予定)
+    tm_editor_param      TEXT                                         NOT NULL,      -- 編集エディタ用パラメータ
+    tm_attr              TEXT                                         NOT NULL,      -- その他属性(「,」区切り)(woocommerce等)
     tm_mobile            BOOLEAN        DEFAULT false                 NOT NULL,      -- 携帯対応かどうか
     tm_use_bootstrap     BOOLEAN        DEFAULT false                 NOT NULL,      -- Bootstrapを使用するかどうか
     tm_available         BOOLEAN        DEFAULT true                  NOT NULL,      -- メニューから選択可能かどうか
+	tm_has_admin         BOOLEAN        DEFAULT false                 NOT NULL,      -- 管理画面があるかどうか
     tm_clean_type        INT            DEFAULT 0                     NOT NULL,      -- 出力のクリーン処理(0=処理なし,0以外=クリーン処理実行)
     
     tm_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
@@ -609,9 +622,10 @@ CREATE TABLE _widgets (
     wd_add_scripts_a     TEXT                                         NOT NULL,      -- (管理機能用)追加スクリプトファイル(相対パス表記、「,」区切りで複数指定可)
     wd_add_css_a         TEXT                                         NOT NULL,      -- (管理機能用)追加CSSファイル(相対パス表記、「,」区切りで複数指定可)
     wd_admin             BOOLEAN        DEFAULT false                 NOT NULL,      -- 管理用ウィジェットかどうか
-    wd_mobile            BOOLEAN        DEFAULT false                 NOT NULL,      -- 携帯対応かどうか
-    wd_show_name         BOOLEAN        DEFAULT false                 NOT NULL,      -- ウィジェット名称を表示するかどうか
-	wd_enable_content    BOOLEAN        DEFAULT false                 NOT NULL,      -- コンテンツ組み込み可能かどうか
+    wd_mobile            BOOLEAN        DEFAULT false                 NOT NULL,      -- 携帯対応かどうか(廃止予定)
+    wd_show_name         BOOLEAN        DEFAULT false                 NOT NULL,      -- ウィジェット名称を表示するかどうか(wd_hide_titleと統合?)
+	wd_hide_title        BOOLEAN        DEFAULT false                 NOT NULL,      -- 実稼働時に強制的にタイトルを非表示にするかどうか(廃止予定?)
+    wd_enable_content    BOOLEAN        DEFAULT false                 NOT NULL,      -- コンテンツ組み込み可能かどうか
     wd_read_scripts      BOOLEAN        DEFAULT false                 NOT NULL,      -- スクリプトディレクトリを自動読み込みするかどうか(廃止予定)
     wd_read_css          BOOLEAN        DEFAULT false                 NOT NULL,      -- cssディレクトリを自動読み込みするかどうか(廃止予定)
     wd_use_ajax          BOOLEAN        DEFAULT false                 NOT NULL,      -- Ajax共通ライブラリを読み込むかどうか
@@ -626,6 +640,7 @@ CREATE TABLE _widgets (
     wd_initialized       BOOLEAN        DEFAULT false                 NOT NULL,      -- 初期化完了かどうか
     wd_use_cache         BOOLEAN        DEFAULT false                 NOT NULL,      -- キャッシュ機能を使用するかどうか
     wd_has_rss           BOOLEAN        DEFAULT false                 NOT NULL,      -- RSS機能があるかどうか
+	wd_personal_mode     BOOLEAN        DEFAULT false                 NOT NULL,      -- パーソナルモード対応かどうか
     wd_priority          INT            DEFAULT 0                     NOT NULL,      -- 優先度
     wd_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート順
 --    wd_cache_interval    INT            DEFAULT 0                     NOT NULL,      -- キャッシュの更新時間(分)
@@ -639,7 +654,7 @@ CREATE TABLE _widgets (
     wd_admin_class       VARCHAR(200)   DEFAULT ''                    NOT NULL,      -- 管理機能起動クラス名
     wd_db                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 対応DB種(mysql,pgsql等を「,」区切りで指定)
     wd_table_access_type INT            DEFAULT 0                     NOT NULL,      -- テーブルのアクセス範囲(0=テーブル未使用、1=共通テーブルのみ、2=独自テーブル)
-	
+
     wd_checked_out       BOOLEAN        DEFAULT false                 NOT NULL,      -- チェックアウト中かどうか
     wd_checked_out_dt    TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- チェックアウト日時
     wd_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
@@ -654,21 +669,12 @@ CREATE TABLE _widgets (
 -- ウィジェットカテゴリマスター
 DROP TABLE IF EXISTS _widget_category;
 CREATE TABLE _widget_category (
-    wt_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
     wt_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- カテゴリID
-    wt_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
-
+    wt_parent_id         VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 親カテゴリID
     wt_name              VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- カテゴリ名称
     wt_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート用
     wt_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示するかどうか
-
-    wt_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
-    wt_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
-    wt_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
-    wt_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
-    wt_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
-    PRIMARY KEY          (wt_serial),
-    UNIQUE               (wt_id,        wt_history_index)
+    PRIMARY KEY          (wt_id)
 ) ENGINE=innodb;
 
 -- ウィジェットパラメータマスター
@@ -704,7 +710,7 @@ DROP TABLE IF EXISTS _iwidgets;
 CREATE TABLE _iwidgets (
     iw_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
     iw_widget_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ウィジェットID(ファイル名)(廃止予定)
-    iw_id                VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- インナーウィジェットID(ファイル名)
+    iw_id                VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- インナーウィジェットID(インナーウィジェットIDフォーマット「ウィジェットID,インナーID」、共通のインナーウィジェットIDフォーマット「インナーID」)
     iw_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
     
     iw_language          TEXT                                         NOT NULL,      -- 対応言語ID(「,」区切りで複数指定可)
@@ -727,7 +733,8 @@ CREATE TABLE _iwidgets (
     iw_admin_file        VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 管理機能起動クラスのファイル名
     iw_admin_class       VARCHAR(200)   DEFAULT ''                    NOT NULL,      -- 管理機能起動クラス名
     iw_db                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 対応DB種(mysql,pgsql等を「,」区切りで指定)
-	
+    iw_params            TEXT                                         NOT NULL,      -- 追加パラメータ(「;」区切り)
+
     iw_checked_out       BOOLEAN        DEFAULT false                 NOT NULL,      -- チェックアウト中かどうか
     iw_checked_out_dt    TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- チェックアウト日時
     iw_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
@@ -779,11 +786,11 @@ CREATE TABLE _page_id (
     pg_path              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アクセスポイントパス(ページID種別がアクセスポイント時使用)
     pg_class             VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 起動クラス名(ページID種別がアクセスポイント時使用)
     pg_device_type       INT            DEFAULT 0                     NOT NULL,      -- 端末タイプ(0=PC、1=携帯、2=スマートフォン)(ページID種別がアクセスポイント時使用)
-	pg_function_type     VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- システム用機能タイプ
+    pg_function_type     VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- システム用機能タイプ
     pg_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ページ名称
     pg_description       VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- 説明
     pg_priority          INT            DEFAULT 0                     NOT NULL,      -- 優先度
-	pg_frontend          BOOLEAN        DEFAULT false                 NOT NULL,      -- フロント画面用かどうか(ページID種別がアクセスポイント時)、pg_analyticsは廃止
+    pg_frontend          BOOLEAN        DEFAULT false                 NOT NULL,      -- フロント画面用かどうか(ページID種別がアクセスポイント時)、pg_analyticsは廃止
     pg_mobile            BOOLEAN        DEFAULT false                 NOT NULL,      -- 携帯対応かどうか(ページID種別がアクセスポイント時使用)
     pg_active            BOOLEAN        DEFAULT true                  NOT NULL,      -- 有効かどうか
     pg_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示可能かどうか
@@ -842,6 +849,8 @@ CREATE TABLE _page_def (
     pd_config_id         INT            DEFAULT 0                     NOT NULL,      -- ウィジェット定義ID
     pd_config_name       VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ウィジェット定義名
     pd_menu_id           VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- メニューID
+    pd_content_type      VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- コンテンツの種別
+    pd_content_id        TEXT                                         NOT NULL,      -- コンテンツID
     pd_suffix            VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- インスタンスを区別するためのサフィックス文字列
     pd_title             TEXT                                         NOT NULL,      -- タイトル
     pd_h_tag_level       INT            DEFAULT 0                     NOT NULL,      -- タイトル用のHタグのトップレベル(0=設定なし、0以外=Hタグレベル)
@@ -852,7 +861,7 @@ CREATE TABLE _page_def (
     pd_view_control_type INT            DEFAULT 0                     NOT NULL,      -- 表示出力の制御タイプ(0=常時表示、1=ログイン時のみ表示、2=非ログイン時のみ表示)
     pd_view_page_state   INT            DEFAULT 0                     NOT NULL,      -- ページ状況での表示制御タイプ(0=常時表示、1=トップ時のみ表示)
     pd_view_option       TEXT                                         NOT NULL,      -- 表示オプション
-	pd_visible_condition TEXT                                         NOT NULL,      -- ウィジェット表示条件。「キー=値」の形式でURLクエリーパラメータを指定。複数のクエリーパラメータ条件は「,」で区切り、条件のまとまりは「;」で区切る。
+    pd_visible_condition TEXT                                         NOT NULL,      -- ウィジェット表示条件。「キー=値」の形式でURLクエリーパラメータを指定。複数のクエリーパラメータ条件は「,」で区切り、条件のまとまりは「;」で区切る。
     pd_edit_status       SMALLINT       DEFAULT 0                     NOT NULL,      -- 編集状態(0=編集完了、1=編集中)
     pd_top_content       TEXT                                         NOT NULL,      -- 上部コンテンツ
     pd_bottom_content    TEXT                                         NOT NULL,      -- 下部コンテンツ
@@ -886,6 +895,27 @@ CREATE TABLE _page_def_set (
     PRIMARY KEY          (ds_id)
 ) ENGINE=innodb;
 
+-- ランディングページ情報マスター
+DROP TABLE IF EXISTS _landing_page;
+CREATE TABLE _landing_page (
+    lp_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    lp_id                VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ランディングページID
+    lp_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+    
+    lp_name              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ページ名
+    lp_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 公開可否
+	lp_owner_id          INT            DEFAULT 0                     NOT NULL,      -- ページの所有者ID
+	lp_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- ページ作成日時
+	
+    lp_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    lp_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    lp_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    lp_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    lp_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (lp_serial),
+    UNIQUE               (lp_id,        lp_history_index)
+) ENGINE=innodb;
+
 -- キャッシュトラン
 DROP TABLE IF EXISTS _cache;
 CREATE TABLE _cache (
