@@ -26,7 +26,7 @@ INSERT INTO _widgets
 DELETE FROM _widgets WHERE wd_id = 'admin_main';
 INSERT INTO _widgets
 (wd_id,        wd_name,      wd_admin, wd_category_id, wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_add_script_lib, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_initialized, wd_release_dt, wd_install_dt, wd_create_dt) VALUES
-('admin_main', '管理用画面', true,     'admin',            '1.1.0', 'Naoki Hirata', 'Magic3.org', 'GPL',      10,                'menudef=jquery.jstree;menudef_detail=wysiwyg_editor;smenudef_detail=wysiwyg_editor;analyzegraph=jquery.jqplot;adjustwidget=wysiwyg_editor,ckeditor_m3toolbar;filebrowse=elfinder;editmenu_others=elfinder;initwizard_=bootstrap;configsys=bootstrap.toggle;pageinfo=bootstrap.toggle;pagedef=bootstrap.toggle;test_ckeditor=ckeditor_m3toolbar;test_config=wysiwyg_editor,ckeditor_m3toolbar;test_input=bootstrap.datetimepicker;test_chat=socketio;test_realtime=socketio;test_voice=webrtc;configimage=jquery.uploadfile;tempimage=jquery.uploadfile;tempimage_detail=jquery.uploadfile;userlist_detail=md5;landingpage_detail=md5', false,        false,       false,        true,          false, true, '2013-03-04', now(),now());
+('admin_main', '管理用画面', true,     'admin',            '1.1.0', 'Naoki Hirata', 'Magic3.org', 'GPL',      10,                'menudef=jquery.jstree;menudef_detail=wysiwyg_editor;smenudef_detail=wysiwyg_editor;analyzegraph=jquery.jqplot;adjustwidget=wysiwyg_editor,ckeditor_m3toolbar;filebrowse=elfinder;editmenu_others=elfinder;initwizard_=bootstrap;configsys=bootstrap.toggle;pageinfo=bootstrap.toggle;pagedef=bootstrap.toggle;test_ckeditor=ckeditor_m3toolbar;test_config=wysiwyg_editor,ckeditor_m3toolbar;test_input=bootstrap.datetimepicker;test_chat=socketio;test_realtime=socketio;test_voice=webrtc;test_upload=jquery.uploadfile;configimage=jquery.uploadfile;tempimage=jquery.uploadfile;tempimage_detail=jquery.uploadfile;userlist_detail=md5;landingpage_detail=md5', false,        false,       false,        true,          false, true, '2013-03-04', now(),now());
 DELETE FROM _widgets WHERE wd_id = 'admin/analytics';
 INSERT INTO _widgets
 (wd_id,             wd_name,            wd_admin, wd_category_id, wd_version, wd_author,      wd_copyright, wd_license, wd_official_level, wd_add_script_lib, wd_available, wd_editable, wd_has_admin, wd_initialized,  wd_release_dt, wd_install_dt, wd_create_dt) VALUES
