@@ -52,6 +52,13 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 	 **/
 	protected $dbError = '';
 
+	/**
+	 * This root has parent id
+	 *
+	 * @var        boolean
+	 */
+	protected $rootHasParent = false;
+
 	/**
 	 * Constructor
 	 * Extend options with required fields
@@ -121,6 +128,9 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 
 		$this->updateCache($this->options['path'], $this->_stat($this->options['path']));
 
+		// enable command archive
+		$this->options['useRemoteArchive'] = true;
+
 		return true;
 	}
 
@@ -148,7 +158,8 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 			$this->tmpPath = $tmp;
 		}
 		
-		if (!$this->tmpPath && $this->tmbPath && $this->tmbPathWritable) {
+		// fallback of $this->tmp
+		if (!$this->tmpPath && $this->tmbPathWritable) {
 			$this->tmpPath = $this->tmbPath;
 		}
 
@@ -207,8 +218,8 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 	 * @author Dmitry (dio) Levashov
 	 **/
 	protected function make($path, $name, $mime) {
-		$sql = 'INSERT INTO %s (`parent_id`, `name`, `size`, `mtime`, `mime`, `content`, `read`, `write`) VALUES (\'%s\', \'%s\', 0, %d, \'%s\', \'\', \'%d\', \'%d\')';
-		$sql = sprintf($sql, $this->tbf, $path, $this->db->real_escape_string($name), time(), $mime, $this->defaults['read'], $this->defaults['write']);
+		$sql = 'INSERT INTO %s (`parent_id`, `name`, `size`, `mtime`, `mime`, `content`, `read`, `write`, `locked`, `hidden`, `width`, `height`) VALUES (\'%s\', \'%s\', 0, %d, \'%s\', \'\', \'%d\', \'%d\', \'%d\', \'%d\', 0, 0)';
+		$sql = sprintf($sql, $this->tbf, $path, $this->db->real_escape_string($name), time(), $mime, $this->defaults['read'], $this->defaults['write'], $this->defaults['locked'], $this->defaults['hidden']);
 		// echo $sql;
 		return $this->query($sql) && $this->db->affected_rows > 0;
 	}
@@ -231,13 +242,13 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 				FROM '.$this->tbf.' AS f 
 				LEFT JOIN '.$this->tbf.' AS ch ON ch.parent_id=f.id AND ch.mime=\'directory\'
 				WHERE f.parent_id=\''.$path.'\'
-				GROUP BY f.id';
+				GROUP BY f.id, ch.id';
 				
 		$res = $this->query($sql);
 		if ($res) {
 			while ($row = $res->fetch_assoc()) {
 				$id = $row['id'];
-				if ($row['parent_id']) {
+				if ($row['parent_id'] && $id != $this->root) {
 					$row['phash'] = $this->encode($row['parent_id']);
 				} 
 				
@@ -311,10 +322,15 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 	 * @author Dmitry (dio) Levashov
 	 **/
 	protected function doSearch($path, $q, $mimes) {
+		if (!empty($this->doSearchCurrentQuery['matchMethod'])) {
+			// has custom match method use elFinderVolumeDriver::doSearch()
+			return parent::doSearch($path, $q, $mimes);
+		}
+
 		$dirs = array();
 		$timeout = $this->options['searchTimeout']? $this->searchStart + $this->options['searchTimeout'] : 0;
 		
-		if ($path != $this->root) {
+		if ($path != $this->root || $this->rootHasParent) {
 			$dirs = $inpath = array(intval($path));
 			while($inpath) {
 				$in = '('.join(',', $inpath).')';
@@ -344,7 +360,7 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 			}
 			$whr = join(' OR ', $whrs);
 		} else {
-			$whr = sprintf('f.name RLIKE \'%s\'', $this->db->real_escape_string($q));
+			$whr = sprintf('f.name LIKE \'%%%s%%\'', $this->db->real_escape_string($q));
 		}
 		if ($dirs) {
 			$whr = '(' . $whr . ') AND (`parent_id` IN (' . join(',', $dirs) . '))';
@@ -367,7 +383,10 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 					continue;
 				}
 				$id = $row['id'];
-				if ($row['parent_id']) {
+				if ($id == $this->root) {
+					continue;
+				}
+				if ($row['parent_id'] && $id != $this->root) {
 					$row['phash'] = $this->encode($row['parent_id']);
 				} 
 				$row['path'] = $this->_path($id);
@@ -387,7 +406,6 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 				}
 			}
 		}
-		
 		return $result;
 	}
 
@@ -525,15 +543,18 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 	protected function _stat($path) {
 		$sql = 'SELECT f.id, f.parent_id, f.name, f.size, f.mtime AS ts, f.mime, f.read, f.write, f.locked, f.hidden, f.width, f.height, IF(ch.id, 1, 0) AS dirs
 				FROM '.$this->tbf.' AS f 
-				LEFT JOIN '.$this->tbf.' AS p ON p.id=f.parent_id
 				LEFT JOIN '.$this->tbf.' AS ch ON ch.parent_id=f.id AND ch.mime=\'directory\'
 				WHERE f.id=\''.$path.'\'
-				GROUP BY f.id';
+				GROUP BY f.id, ch.id';
 
 		$res = $this->query($sql);
 		
 		if ($res) {
 			$stat = $res->fetch_assoc();
+			if ($stat['id'] == $this->root) {
+				$this->rootHasParent = true;
+				$stat['parent_id'] = '';
+			}
 			if ($stat['parent_id']) {
 				$stat['phash'] = $this->encode($stat['parent_id']);
 			} 
@@ -542,6 +563,9 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 				unset($stat['height']);
 				$stat['size'] = 0;
 			} else {
+				if (!$stat['mime']) {
+					unset($stat['mime']);
+				}
 				unset($stat['dirs']);
 			}
 			unset($stat['id']);
@@ -602,7 +626,7 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 	protected function _fopen($path, $mode='rb') {
 		$fp = $this->tmbPath
 			? fopen($this->getTempFile($path), 'w+')
-			: tmpfile();
+			: $this->tmpfile();
 		
 		
 		if ($fp) {
@@ -628,9 +652,10 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 	 * @author Dmitry (dio) Levashov
 	 */
 	protected function _fclose($fp, $path='') {
-		fclose($fp);
+		is_resource($fp) && fclose($fp);
 		if ($path) {
-			unlink($this->getTempFile($path));
+			$file = $this->getTempFile($path);
+			is_file($file) && unlink($file);
 		}
 	}
 	
@@ -657,7 +682,7 @@ class elFinderVolumeMySQL extends elFinderVolumeDriver {
 	 * @author Dmitry (dio) Levashov
 	 **/
 	protected function _mkfile($path, $name) {
-		return $this->make($path, $name, 'text/plain') ? $this->_joinPath($path, $name) : false;
+		return $this->make($path, $name, '') ? $this->_joinPath($path, $name) : false;
 	}
 
 	/**
