@@ -20,48 +20,32 @@ require_once(M3_SYSTEM_INCLUDE_PATH . '/common/scriptLibInfo.php');
 class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $adminTheme;		// 管理画面用jQueryUIテーマ
-	private $defaultTheme;		// フロント画面用jQueryUIテーマ
 	private $systemTemplate;// システム画面用テンプレート
 	private $jqueryVersion;			// jQueryバージョン
-	private $wysiwygMenuData;		// WYSIWYGエディター選択メニューデータ
-	private $wysiwygEditor;			// 管理画面用WYSIWYGエディター
-	const DEFAULT_THEME_DIR = '/ui/themes';				// jQueryUIテーマ格納ディレクトリ
 	const DEFAULT_SYSTEM_TEMPLATE_ID = '_system';				// デフォルトのシステム画面用テンプレート
-	const DEFAULT_JQUERY_VERSION = '1.8';				// デフォルトのjQueryバージョン
+	const DEFAULT_JQUERY_VERSION = '1.9';				// デフォルトのjQueryバージョン
 	
 	// DB定義値
 	const CF_USE_SSL = 'use_ssl';		// SSL機能を使用するかどうか
 	const CF_USE_SSL_ADMIN = 'use_ssl_admin';		// 管理画面にSSL機能を使用するかどうか
 	const CF_SITE_IN_PUBLIC = 'site_in_public';			// サイト公開状況
 	const CF_SITE_PC_IN_PUBLIC = 'site_pc_in_public';				// PC用サイトの公開状況
-	const CF_SITE_MOBILE_IN_PUBLIC = 'site_mobile_in_public';		// 携帯用サイトの公開状況
 	const CF_SITE_SMARTPHONE_IN_PUBLIC = 'site_smartphone_in_public';		// スマートフォン用サイトの公開状況
-	const CF_MOBILE_AUTO_REDIRECT = 'mobile_auto_redirect';					// 携帯の自動遷移
 	const CF_SMARTPHONE_AUTO_REDIRECT = 'smartphone_auto_redirect';			// スマートフォンの自動遷移
 	const CF_SITE_SMARTPHONE_URL = 'site_smartphone_url';		// スマートフォン用サイトURL
-	const CF_SITE_MOBILE_URL = 'site_mobile_url';		// 携帯用サイトURL
 	const CF_SITE_OPERATION_MODE = 'site_operation_mode';			// サイト運用モード
 	const CF_ACCESS_IN_INTRANET = 'access_in_intranet';		// イントラネット運用
 	const CF_MULTI_DOMAIN = 'multi_domain';		// マルチドメイン運用
 	const CF_USE_LANDING_PAGE = 'use_landing_page';		// ランディングページ機能を使用するかどうか
 	const CF_SITE_ACCESS_EXCEPTION_IP = 'site_access_exception_ip';		// アクセス制御、例外とするIP
-	const CF_MOBILE_USE_SESSION = 'mobile_use_session';		// 携帯でセッション管理を行うかどうか
 	const CF_USE_PAGE_CACHE = 'use_page_cache';		// 画面キャッシュ機能を使用するかどうか
-	const CF_USE_TEMPLATE_ID_IN_SESSION = 'use_template_id_in_session';			// セッションにテンプレートIDを保存
 	const CF_SSL_URL = 'ssl_root_url';				// SSL用のルートURL
 	const CF_CONNECT_SERVER_URL = 'default_connect_server_url';			// ポータル接続先URL
-	const CF_CONFIG_WINDOW_OPEN_TYPE = 'config_window_open_type';		// ウィジェット設定画面のウィンドウ表示タイプ(0=別ウィンドウ、1=タブ)
 	const CF_SYSTEM_TEMPLATE = 'msg_template';			// メッセージ用テンプレート取得キー
-	const CF_ADMIN_DEFAULT_THEME = 'admin_default_theme';		// 管理画面用jQueryUIテーマ
-	const CF_DEFAULT_THEME = 'default_theme';		// フロント画面用jQueryUIテーマ
 	const CF_HIERARCHICAL_PAGE = 'hierarchical_page';		// 階層化ページを使用するかどうか
 	const CF_MULTI_LANGUAGE = 'multi_language';			// 多言語対応
 	const CF_JQUERY_VERSION = 'jquery_version';			// jQueryバージョン
 	const CF_EXTERNAL_JQUERY = 'external_jquery';			// システム外部のjQueryを使用するかどうか
-//	const CF_USE_JQUERY = 'use_jquery';			// jQueryを常に使用するかどうか
-	const CF_SMARTPHONE_USE_JQUERY_MOBILE = 'smartphone_use_jquery_mobile';		// スマートフォン画面でjQuery Mobileを使用
-	const CF_WYSIWYG_EDITOR = 'wysiwyg_editor';		// 管理画面用WYSIWYGエディター
 	const CF_MULTI_DEVICE_ADMIN = 'multi_device_admin';			// マルチデバイス最適化管理画面
 	const CF_PERMIT_DETAIL_CONFIG	= 'permit_detail_config';				// 詳細設定が可能かどうか
 	const CF_DEFAULT_LANG		= 'default_lang';					// デフォルト言語
@@ -77,8 +61,6 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		
 		// DB接続オブジェクト作成
 		$this->db = new admin_mainDb();
-		
-		$this->wysiwygMenuData = array('fckeditor' => 'FCKEditor 2.6.6', 'ckeditor' => 'CKEditor 4.4.2');		// WYSIWYGエディター選択メニューデータ
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -128,35 +110,23 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		$sslUrl = $request->trimValueOf('item_ssl_url');			// SSL用のURL
 		$connectServerUrl = $request->trimValueOf('item_connect_server_url');			// ポータル接続先URL
 		$siteSmartphoneUrl = $request->trimValueOf('item_site_smartphone_url');		// スマートフォン用サイトURL
-		$siteMobileUrl = $request->trimValueOf('item_site_mobile_url');		// 携帯用サイトURL
 		$usePageCache = ($request->trimValueOf('item_use_page_cache') == 'on') ? 1 : 0;		// 表示キャッシュ機能を使用するかどうか
-		$canChangeTemplate = ($request->trimValueOf('item_can_change_template') == 'on') ? 1 : 0;		// ユーザによるテンプレート変更を許可するかどうか
 		$canDetailConfig = ($request->trimValueOf('item_can_detail_config') == 'on') ? 1 : 0;		// 詳細システム設定が可能かどうか
 		$multiDeviceAdmin = ($request->trimValueOf('item_multi_device_admin') == 'on') ? 1 : 0;// マルチデバイス最適化管理画面
-		$mobileAutoRedirect = ($request->trimValueOf('item_mobile_auto_redirect') == 'on') ? 1 : 0;		// 携帯の自動遷移
 		$smartphoneAutoRedirect = ($request->trimValueOf('item_smartphone_auto_redirect') == 'on') ? 1 : 0;		// スマートフォンの自動遷移
-		$mobileUseSession = ($request->trimValueOf('item_mobile_use_session') == 'on') ? 1 : 0;		// 携帯でセッション管理するかどうか
 		$sitePcInPublic = ($request->trimValueOf('item_site_pc_in_public') == 'on') ? 1 : 0;			// PC用サイトの公開状況
-		$siteMobileInPublic = ($request->trimValueOf('item_site_mobile_in_public') == 'on') ? 1 : 0;	// 携帯用サイトの公開状況
 		$siteSmartphoneInPublic = ($request->trimValueOf('item_site_smartphone_in_public') == 'on') ? 1 : 0;	// スマートフォン用サイトの公開状況
 		$accessInIntranet	= $request->trimCheckedValueOf('item_access_in_intranet');		// イントラネット運用
 		$multiDomain = ($request->trimValueOf('item_multi_domain') == 'on') ? 1 : 0;// マルチドメイン運用
 		$useLandingPage		= $request->trimCheckedValueOf('item_use_landing_page');	// ランディングページ機能を使用するかどうか
 		$isActiveSitePc = ($request->trimValueOf('item_is_active_site_pc') == 'on') ? 1 : 0;	// PC用サイト有効
 		$isActiveSiteSmartphone = ($request->trimValueOf('item_is_active_site_smartphone') == 'on') ? 1 : 0;	// スマートフォン用サイト有効
-		$isActiveSiteMobile = ($request->trimValueOf('item_is_active_site_mobile') == 'on') ? 1 : 0;	// 携帯用サイト有効
-		$configWindowOpenByTab = ($request->trimValueOf('item_config_window_open_by_tab') == 'on') ? 1 : 0;			// ウィジェット設定画面をタブで開くかどうか
 		$multiLanguage = ($request->trimValueOf('item_multi_language') == 'on') ? 1 : 0;			// 多言語対応
 		$lang = $request->trimValueOf('item_lang');
 		$workDir = $request->trimValueOf('item_work_dir');
 		$this->systemTemplate = $request->trimValueOf('item_systemplate');	// システム画面用テンプレート
-		$this->adminTheme = $request->trimValueOf('item_admin_theme');		// 管理画面用jQueryUIテーマ
-		$this->defaultTheme = $request->trimValueOf('item_default_theme');		// フロント画面用jQueryUIテーマ
 		$this->jqueryVersion = $request->trimValueOf('item_jquery_version');		// jQueryバージョン
 		$externalJquery = $request->trimCheckedValueOf('item_external_jquery');		// システム外部のjQueryを使用するかどうか
-//		$useJquery = ($request->trimValueOf('item_use_jquery') == 'on') ? 1 : 0;			// 常にjQueryを使用するかどうか
-		$smartphoneUseJqueryMobile = ($request->trimValueOf('item_smartphone_use_jquery_mobile') == 'on') ? 1 : 0;// スマートフォン画面でjQuery Mobileを使用
-		$this->wysiwygEditor = $request->trimValueOf('item_wysiwyg_editor');			// 管理画面用WYSIWYGエディター
 		$uploadImageAutoresize = $request->trimCheckedValueOf('item_upload_image_autoresize');		// アップロード画像の自動リサイズを行うかどうか
 		$uploadImageAutoresizeMaxWidth = $request->trimValueOf('item_upload_image_autoresize_max_width');		// アップロード画像の自動リサイズ、画像最大幅
 		$uploadImageAutoresizeMaxHeight = $request->trimValueOf('item_upload_image_autoresize_max_height');		// アップロード画像の自動リサイズ、画像最大高さ
@@ -173,28 +143,18 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			if (!$isErr) if (!$this->db->updateSystemConfig(self::CF_USE_SSL_ADMIN, $useSslAdmin)) $isErr = true;			// SSL機能を使用するかどうか
 			if (!$isErr) if (!$this->db->updateSystemConfig(self::CF_HIERARCHICAL_PAGE, $useHierPage)) $isErr = true;			// 階層化ページを使用するかどうか
 			if (!$isErr) if (!$this->db->updateSystemConfig(self::CF_USE_PAGE_CACHE, $usePageCache)) $isErr = true;			// 表示キャッシュ機能を使用するかどうか
-			if (!$isErr) if (!$this->db->updateSystemConfig(self::CF_USE_TEMPLATE_ID_IN_SESSION, $canChangeTemplate)) $isErr = true;// ユーザによるテンプレート変更を許可するかどうか
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CF_PERMIT_DETAIL_CONFIG, $canDetailConfig)) $isErr = true;
 			}
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CF_MULTI_DEVICE_ADMIN, $multiDeviceAdmin)) $isErr = true;// マルチデバイス最適化管理画面
 			}
-			if (!$isErr){
-				if (!$this->db->updateSystemConfig(self::CF_MOBILE_AUTO_REDIRECT, $mobileAutoRedirect)) $isErr = true;
-			}
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CF_SMARTPHONE_AUTO_REDIRECT, $smartphoneAutoRedirect)) $isErr = true;
 			}
-			if (!$isErr){
-				if (!$this->db->updateSystemConfig(self::CF_MOBILE_USE_SESSION, $mobileUseSession)) $isErr = true;// 携帯でセッション管理するかどうか
-			}
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CF_SITE_PC_IN_PUBLIC, $sitePcInPublic)) $isErr = true;
 			}
-			if (!$isErr){
-				if (!$this->db->updateSystemConfig(self::CF_SITE_MOBILE_IN_PUBLIC, $siteMobileInPublic)) $isErr = true;
-			}
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CF_SITE_SMARTPHONE_IN_PUBLIC, $siteSmartphoneInPublic)) $isErr = true;
 			}
@@ -213,12 +173,6 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			if (!$isErr){
 				if (!$this->updateActiveAccessPoint(2/*スマートフォン*/, $isActiveSiteSmartphone)) $isErr = true;// スマートフォン用サイト有効
 			}
-			if (!$isErr){
-				if (!$this->updateActiveAccessPoint(1/*携帯*/, $isActiveSiteMobile)) $isErr = true;// 携帯用サイト有効
-			}
-			if (!$isErr){
-				if (!$this->db->updateSystemConfig(self::CF_CONFIG_WINDOW_OPEN_TYPE, $configWindowOpenByTab)) $isErr = true;			// ウィジェット設定画面をタブで開くかどうか
-			}
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CF_MULTI_LANGUAGE, $multiLanguage)) $isErr = true;			// 多言語対応
 			}
@@ -235,10 +189,6 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 				$siteSmartphoneUrl = rtrim($siteSmartphoneUrl, '/');// 最後の「/」を除く
 				if (!$this->db->updateSystemConfig(self::CF_SITE_SMARTPHONE_URL, $siteSmartphoneUrl)) $isErr = true;// スマートフォン用サイトURL
 			}
-			if (!$isErr){
-				$siteMobileUrl = rtrim($siteMobileUrl, '/');// 最後の「/」を除く
-				if (!$this->db->updateSystemConfig(self::CF_SITE_MOBILE_URL, $siteMobileUrl)) $isErr = true;// 携帯用サイトURL
-			}
 			if (!$isErr){
 				$workDir = rtrim($workDir, '/');// 最後の「/」を除く
 				if (!$this->db->updateSystemConfig(self::CF_WORK_DIR, $workDir)) $isErr = true;
@@ -246,28 +196,12 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CF_SYSTEM_TEMPLATE, $this->systemTemplate)) $isErr = true;// システム画面用テンプレート
 			}
-			// 管理画面用jQueryUIテーマは「smoothness」に固定(2017/4/25)
-//			if (!$isErr){
-//				if (!$this->db->updateSystemConfig(self::CF_ADMIN_DEFAULT_THEME, $this->adminTheme)) $isErr = true;// 管理画面用jQueryUIテーマ
-//			}
-			if (!$isErr){
-				if (!$this->db->updateSystemConfig(self::CF_DEFAULT_THEME, $this->defaultTheme)) $isErr = true;// フロント画面用jQueryUIテーマ
-			}
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CF_JQUERY_VERSION, $this->jqueryVersion)) $isErr = true;// jQueryバージョン
 			}
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(self::CF_EXTERNAL_JQUERY, $externalJquery)) $isErr = true;// システム外部のjQueryを使用するかどうか
 			}
-/*			if (!$isErr){
-				if (!$this->db->updateSystemConfig(self::CF_USE_JQUERY, $useJquery)) $isErr = true;// 常にjQueryを使用するかどうか
-			}*/
-			if (!$isErr){
-				if (!$this->db->updateSystemConfig(self::CF_SMARTPHONE_USE_JQUERY_MOBILE, $smartphoneUseJqueryMobile)) $isErr = true;// スマートフォン画面でjQuery Mobileを使用
-			}
-			if (!$isErr){
-				if (!$this->db->updateSystemConfig(self::CF_WYSIWYG_EDITOR, $this->wysiwygEditor)) $isErr = true;// 管理画面用WYSIWYGエディター
-			}		
 			if (!$isErr){
 				if (!$this->db->updateSystemConfig(SystemManager::CF_UPLOAD_IMAGE_AUTORESIZE, $uploadImageAutoresize)) $isErr = true;		// アップロード画像の自動リサイズを行うかどうか
 			}
@@ -297,36 +231,23 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			$sslUrl				= $this->db->getSystemConfig(self::CF_SSL_URL);			// SSLのURL
 			$connectServerUrl	= $this->db->getSystemConfig(self::CF_CONNECT_SERVER_URL);// ポータル接続先URL
 			$usePageCache 		= $this->db->getSystemConfig(self::CF_USE_PAGE_CACHE);			// 表示キャッシュ機能を使用するかどうか
-			$canChangeTemplate	= $this->db->getSystemConfig(self::CF_USE_TEMPLATE_ID_IN_SESSION);// ユーザによるテンプレート変更を許可するかどうか
 			$canDetailConfig	= $this->db->getSystemConfig(self::CF_PERMIT_DETAIL_CONFIG);
 			$multiDeviceAdmin	= $this->db->getSystemConfig(self::CF_MULTI_DEVICE_ADMIN);		// マルチデバイス最適化管理画面
-//			$mobileAutoRedirect	= $this->db->getSystemConfig(self::CF_MOBILE_AUTO_REDIRECT);
-			$mobileAutoRedirect	= $this->gSystem->mobileAutoRedirect(true/*再取得*/);				// 携帯の自動遷移
 			$smartphoneAutoRedirect	= $this->gSystem->smartphoneAutoRedirect(true/*再取得*/);		// スマートフォンの自動遷移
-			$mobileUseSession = $this->db->getSystemConfig(self::CF_MOBILE_USE_SESSION);// 携帯でセッション管理するかどうか
 			$workDir = $this->db->getSystemConfig(self::CF_WORK_DIR);
 			$sitePcInPublic = $this->gSystem->sitePcInPublic(true/*再取得*/);			// PC用サイトの公開状況
-			$siteMobileInPublic = $this->gSystem->siteMobileInPublic(true/*再取得*/);	// 携帯用サイトの公開状況
 			$siteSmartphoneInPublic = $this->gSystem->siteSmartphoneInPublic(true/*再取得*/);	// スマートフォン用サイトの公開状況
 			$accessInIntranet	= $this->db->getSystemConfig(self::CF_ACCESS_IN_INTRANET);		// イントラネット運用
 			$multiDomain		= $this->db->getSystemConfig(self::CF_MULTI_DOMAIN);			// マルチドメイン運用
 			$useLandingPage		= $this->db->getSystemConfig(self::CF_USE_LANDING_PAGE);// ランディングページ機能を使用するかどうか
 			$isActiveSitePc			= $this->isActiveAccessPoint(0/*PC*/);					// PC用サイト有効かどうか
 			$isActiveSiteSmartphone	= $this->isActiveAccessPoint(2/*スマートフォン*/);		// スマートフォン用サイト有効かどうか
-			$isActiveSiteMobile		= $this->isActiveAccessPoint(1/*スマートフォン*/);		// 携帯用サイト有効かどうか
 			$siteSmartphoneUrl = $this->db->getSystemConfig(self::CF_SITE_SMARTPHONE_URL);		// スマートフォン用サイトURL
-			$siteMobileUrl = $this->db->getSystemConfig(self::CF_SITE_MOBILE_URL);		// 携帯用サイトURL
-			$configWindowOpenByTab = $this->db->getSystemConfig(self::CF_CONFIG_WINDOW_OPEN_TYPE);			// ウィジェット設定画面をタブで開くかどうか
 			$multiLanguage = $this->gSystem->getSystemConfig(self::CF_MULTI_LANGUAGE);		// 多言語対応かどうか
 			$this->systemTemplate		= $this->db->getSystemConfig(self::CF_SYSTEM_TEMPLATE);// システム画面用テンプレート
-			$this->adminTheme = $this->db->getSystemConfig(self::CF_ADMIN_DEFAULT_THEME);		// 管理画面用jQueryUIテーマ
-			$this->defaultTheme = $this->db->getSystemConfig(self::CF_DEFAULT_THEME);		// フロント画面用jQueryUIテーマ
 			$this->jqueryVersion = $this->db->getSystemConfig(self::CF_JQUERY_VERSION);		// jQueryバージョン
 			if (empty($this->jqueryVersion)) $this->jqueryVersion = self::DEFAULT_JQUERY_VERSION;
 			$externalJquery = $this->db->getSystemConfig(self::CF_EXTERNAL_JQUERY);// システム外部のjQueryを使用するかどうか
-//			$useJquery = $this->db->getSystemConfig(self::CF_USE_JQUERY);// 常にjQueryを使用するかどうか
-			$smartphoneUseJqueryMobile = $this->db->getSystemConfig(self::CF_SMARTPHONE_USE_JQUERY_MOBILE);// スマートフォン画面でjQuery Mobileを使用
-			$this->wysiwygEditor = $this->db->getSystemConfig(self::CF_WYSIWYG_EDITOR);			// 管理画面用WYSIWYGエディター
 			$uploadImageAutoresize = $this->db->getSystemConfig(SystemManager::CF_UPLOAD_IMAGE_AUTORESIZE);		// アップロード画像の自動リサイズを行うかどうか
 			$uploadImageAutoresizeMaxWidth = $this->db->getSystemConfig(SystemManager::CF_UPLOAD_IMAGE_AUTORESIZE_MAX_WIDTH);	// アップロード画像の自動リサイズ、画像最大幅
 			$uploadImageAutoresizeMaxHeight = $this->db->getSystemConfig(SystemManager::CF_UPLOAD_IMAGE_AUTORESIZE_MAX_HEIGHT);	// アップロード画像の自動リサイズ、画像最大高さ
@@ -379,36 +300,23 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			$sslUrl				= $this->db->getSystemConfig(self::CF_SSL_URL);			// SSLのURL
 			$connectServerUrl	= $this->db->getSystemConfig(self::CF_CONNECT_SERVER_URL);// ポータル接続先URL
 			$usePageCache 		= $this->db->getSystemConfig(self::CF_USE_PAGE_CACHE);			// 表示キャッシュ機能を使用するかどうか
-			$canChangeTemplate	= $this->db->getSystemConfig(self::CF_USE_TEMPLATE_ID_IN_SESSION);// ユーザによるテンプレート変更を許可するかどうか
 			$canDetailConfig	= $this->db->getSystemConfig(self::CF_PERMIT_DETAIL_CONFIG);
 			$multiDeviceAdmin	= $this->db->getSystemConfig(self::CF_MULTI_DEVICE_ADMIN);		// マルチデバイス最適化管理画面
-//			$mobileAutoRedirect	= $this->db->getSystemConfig(self::CF_MOBILE_AUTO_REDIRECT);
-			$mobileAutoRedirect	= $this->gSystem->mobileAutoRedirect(true/*再取得*/);				// 携帯の自動遷移
 			$smartphoneAutoRedirect	= $this->gSystem->smartphoneAutoRedirect(true/*再取得*/);		// スマートフォンの自動遷移
-			$mobileUseSession = $this->db->getSystemConfig(self::CF_MOBILE_USE_SESSION);// 携帯でセッション管理するかどうか
 			$workDir				= $this->db->getSystemConfig(self::CF_WORK_DIR);
 			$sitePcInPublic = $this->gSystem->sitePcInPublic(true/*再取得*/);			// PC用サイトの公開状況
-			$siteMobileInPublic = $this->gSystem->siteMobileInPublic(true/*再取得*/);	// 携帯用サイトの公開状況
 			$siteSmartphoneInPublic = $this->gSystem->siteSmartphoneInPublic(true/*再取得*/);	// スマートフォン用サイトの公開状況
 			$accessInIntranet	= $this->db->getSystemConfig(self::CF_ACCESS_IN_INTRANET);		// イントラネット運用
 			$multiDomain		= $this->db->getSystemConfig(self::CF_MULTI_DOMAIN);// マルチドメイン運用
 			$useLandingPage		= $this->db->getSystemConfig(self::CF_USE_LANDING_PAGE);// ランディングページ機能を使用するかどうか
 			$isActiveSitePc			= $this->isActiveAccessPoint(0/*PC*/);					// PC用サイト有効かどうか
 			$isActiveSiteSmartphone	= $this->isActiveAccessPoint(2/*スマートフォン*/);		// スマートフォン用サイト有効かどうか
-			$isActiveSiteMobile		= $this->isActiveAccessPoint(1/*スマートフォン*/);		// 携帯用サイト有効かどうか
 			$siteSmartphoneUrl = $this->db->getSystemConfig(self::CF_SITE_SMARTPHONE_URL);		// スマートフォン用サイトURL
-			$siteMobileUrl = $this->db->getSystemConfig(self::CF_SITE_MOBILE_URL);		// 携帯用サイトURL
-			$configWindowOpenByTab = $this->db->getSystemConfig(self::CF_CONFIG_WINDOW_OPEN_TYPE);			// ウィジェット設定画面をタブで開くかどうか
 			$multiLanguage = $this->gSystem->getSystemConfig(self::CF_MULTI_LANGUAGE);		// 多言語対応かどうか
 			$this->systemTemplate		= $this->db->getSystemConfig(self::CF_SYSTEM_TEMPLATE);// システム画面用テンプレート
-			$this->adminTheme = $this->db->getSystemConfig(self::CF_ADMIN_DEFAULT_THEME);		// 管理画面用jQueryUIテーマ
-			$this->defaultTheme = $this->db->getSystemConfig(self::CF_DEFAULT_THEME);		// フロント画面用jQueryUIテーマ
 			$this->jqueryVersion = $this->db->getSystemConfig(self::CF_JQUERY_VERSION);		// jQueryバージョン
 			if (empty($this->jqueryVersion)) $this->jqueryVersion = self::DEFAULT_JQUERY_VERSION;
 			$externalJquery = $this->db->getSystemConfig(self::CF_EXTERNAL_JQUERY);// システム外部のjQueryを使用するかどうか
-//			$useJquery = $this->db->getSystemConfig(self::CF_USE_JQUERY);// 常にjQueryを使用するかどうか
-			$smartphoneUseJqueryMobile = $this->db->getSystemConfig(self::CF_SMARTPHONE_USE_JQUERY_MOBILE);// スマートフォン画面でjQuery Mobileを使用
-			$this->wysiwygEditor = $this->db->getSystemConfig(self::CF_WYSIWYG_EDITOR);			// 管理画面用WYSIWYGエディター
 			$uploadImageAutoresize = $this->db->getSystemConfig(SystemManager::CF_UPLOAD_IMAGE_AUTORESIZE);		// アップロード画像の自動リサイズを行うかどうか
 			$uploadImageAutoresizeMaxWidth = $this->db->getSystemConfig(SystemManager::CF_UPLOAD_IMAGE_AUTORESIZE_MAX_WIDTH);	// アップロード画像の自動リサイズ、画像最大幅
 			$uploadImageAutoresizeMaxHeight = $this->db->getSystemConfig(SystemManager::CF_UPLOAD_IMAGE_AUTORESIZE_MAX_HEIGHT);	// アップロード画像の自動リサイズ、画像最大高さ
@@ -420,24 +328,14 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		// システム画面用テンプレート作成
 		$this->db->getAllTemplateList(0/*PC用*/, array($this, 'sysTemplateLoop'), false/*利用不可も表示*/);
 		
-		// jQueryUIテーマ選択メニュー作成
-		$this->createAdminThemeMenu($this->gEnv->getSystemRootPath() . self::DEFAULT_THEME_DIR);
-		$this->createDefaultThemeMenu($this->gEnv->getSystemRootPath() . self::DEFAULT_THEME_DIR);
-		
 		// jQueryバージョン選択メニュー作成
 		$this->createJqueryVerMenu(ScriptLibInfo::getJQueryVersionInfo());
 		
-		// WYSIWYGエディター選択メニュー作成
-		$this->createWysiwygMenu();
-		
 		// サイトURL
 		$this->tmpl->addVar("_widget", "site_url", $this->gEnv->getRootUrl());
 		$this->tmpl->addVar("show_site_pc_open", "pc_access_url", $this->gEnv->getDefaultUrl());
-		$this->tmpl->addVar("show_site_mobile_open", "mobile_access_url", $this->gEnv->getDefaultMobileUrl());
 		$this->tmpl->addVar("show_site_smartphone_open", "smartphone_access_url", $this->gEnv->getDefaultSmartphoneUrl());
 		$this->tmpl->addVar("_widget", "admin_access_url", $this->gEnv->getDefaultAdminUrl());
-		// 携帯画面エンコード
-		$this->tmpl->addVar("show_site_mobile_open", "mobile_encode", $this->gEnv->getMobileEncoding());
 		
 		// サイト運用状況を設定
 		$checked = '';
@@ -455,12 +353,6 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		} else {
 			$this->tmpl->setAttribute('show_site_pc_close', 'visibility', 'visible');
 		}
-		$isActiveSite = $this->gSystem->getSiteActiveStatus(1);		// 携帯用サイト
-		if ($isActiveSite){
-			$this->tmpl->setAttribute('show_site_mobile_open', 'visibility', 'visible');
-		} else {
-			$this->tmpl->setAttribute('show_site_mobile_close', 'visibility', 'visible');
-		}
 		$isActiveSite = $this->gSystem->getSiteActiveStatus(2);		// スマートフォン用サイト
 		if ($isActiveSite){
 			$this->tmpl->setAttribute('show_site_smartphone_open', 'visibility', 'visible');
@@ -489,9 +381,6 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		if ($sitePcInPublic) $checked = 'checked';
 		$this->tmpl->addVar("show_site_pc_open", "site_pc_in_public", $checked);// PC用サイトの公開状況
 		$checked = '';
-		if ($siteMobileInPublic) $checked = 'checked';
-		$this->tmpl->addVar("show_site_mobile_open", "site_mobile_in_public", $checked);// 携帯用サイトの公開状況
-		$checked = '';
 		if ($siteSmartphoneInPublic) $checked = 'checked';
 		$this->tmpl->addVar("show_site_smartphone_open", "site_smartphone_in_public", $checked);// スマートフォン用サイトの公開状況
 		$this->tmpl->addVar("_widget", "access_in_intranet", $this->convertToCheckedString($accessInIntranet));// イントラネット運用
@@ -506,9 +395,6 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		if ($isActiveSiteSmartphone) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "is_active_site_smartphone", $checked);// スマートフォン用サイト有効
 		$checked = '';
-		if ($isActiveSiteMobile) $checked = 'checked';
-		$this->tmpl->addVar("_widget", "is_active_site_mobile", $checked);// 携帯用サイト有効
-		$checked = '';
 		if ($useSsl) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "use_ssl", $checked);// SSL機能を使用するかどうか
 		$checked = '';
@@ -521,18 +407,9 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		if ($usePageCache) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "use_page_cache", $checked);	// 表示キャッシュ機能を使用するかどうか
 		$checked = '';
-		if ($canChangeTemplate) $checked = 'checked';
-		$this->tmpl->addVar("_widget", "can_change_template", $checked);	// ユーザによるテンプレート変更を許可するかどうか
-		$checked = '';
 		if ($multiLanguage) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "multi_language", $checked);	// 多言語対応かどうか
 		$this->tmpl->addVar("_widget", "external_jquery", $this->convertToCheckedString($externalJquery));// システム外部のjQueryを使用するかどうか
-//		$checked = '';
-//		if ($useJquery) $checked = 'checked';
-//		$this->tmpl->addVar("_widget", "use_jquery", $checked);		// 常にjQueryを使用するかどうか
-		$checked = '';
-		if ($smartphoneUseJqueryMobile) $checked = 'checked';
-		$this->tmpl->addVar("_widget", "smartphone_use_jquery_mobile", $checked);		// スマートフォン画面でjQuery Mobileを使用
 		if ($isHier){		// 階層化メニューのとき
 			$this->tmpl->addVar("_widget", "menu_type_tree", 'checked');		// 多階層メニュー
 		} else {
@@ -543,7 +420,6 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		$this->tmpl->addVar("_widget", "root_url", $this->gEnv->getRootUrl());
 		$this->tmpl->addVar("_widget", "connect_server_url", $connectServerUrl);// ポータル接続先URL
 		$this->tmpl->addVar("_widget", "site_smartphone_url", $siteSmartphoneUrl);		// スマートフォン用サイトURL
-		$this->tmpl->addVar("_widget", "site_mobile_url", $siteMobileUrl);		// 携帯用サイトURL
 		
 		// 共有SSL用のURL
 		if (!empty($sslUrl)){
@@ -559,17 +435,8 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		$this->tmpl->addVar("_widget", "can_detail_config", $checked);
 		$this->tmpl->addVar("_widget", "multi_device_admin", $this->convertToCheckedString($multiDeviceAdmin));// マルチデバイス最適化管理画面
 		$checked = '';
-		if (!empty($mobileAutoRedirect)) $checked = 'checked';
-		$this->tmpl->addVar("_widget", "mobile_auto_redirect", $checked);// 携帯の自動遷移
-		$checked = '';
 		if (!empty($smartphoneAutoRedirect)) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "smartphone_auto_redirect", $checked);// スマートフォンの自動遷移
-		$checked = '';
-		if (!empty($mobileUseSession)) $checked = 'checked';
-		$this->tmpl->addVar("_widget", "mobile_use_session", $checked);
-		$checked = '';
-		if (!empty($configWindowOpenByTab)) $checked = 'checked'; 			// ウィジェット設定画面をタブで開くかどうか
-		$this->tmpl->addVar("_widget", "config_window_open_by_tab", $checked);
 
 		$this->tmpl->addVar("_widget", "upload_image_autoresize", $this->convertToCheckedString($uploadImageAutoresize));			// アップロード画像の自動リサイズを行うかどうか
 		$this->tmpl->addVar("_widget", "upload_image_autoresize_max_width", $uploadImageAutoresizeMaxWidth);		// アップロード画像の自動リサイズ、画像最大幅
@@ -679,79 +546,6 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 		$this->tmpl->parseTemplate('lang_list', 'a');
 		return true;
 	}
-	/**
-	 * jQueryUIテーマの選択メニューを作成
-	 *
-	 * @param string $dir		テーマのディレクトリ
-	 * @return 					なし
-	 */
-	function createAdminThemeMenu($themeDir)
-	{
-		if (is_dir($themeDir)){
-			$dir = dir($themeDir);
-			while (($file = $dir->read()) !== false){
-				$filePath = $themeDir . '/' . $file;
-				// ディレクトリかどうかチェック
-				if (strncmp($file, '.', 1) != 0 && $file != '..' && is_dir($filePath) &&
-					strncmp($file, '_', 1) != 0){	// 「_」で始まる名前のディレクトリは読み込まない
-
-					$selected = '';
-					if ($file == $this->adminTheme) $selected = 'selected';
-					
-					$row = array(
-						'value'    => $this->convertToDispString($file),			// テーマID
-						'name'     => $this->convertToDispString($file),
-						'selected' => $selected			// 選択中かどうか
-					);
-					$this->tmpl->addVars('admin_theme_list', $row);
-					$this->tmpl->parseTemplate('admin_theme_list', 'a');
-				}
-			}
-			$dir->close();
-		}
-	}
-	/**
-	 * jQueryUIテーマの選択メニューを作成
-	 *
-	 * @param string $dir		テーマのディレクトリ
-	 * @return 					なし
-	 */
-	function createDefaultThemeMenu($themeDir)
-	{
-		$selected = '';
-		if (empty($this->defaultTheme)) $selected = 'selected';
-		
-		$row = array(
-			'value'    => '',			// テーマID
-			'name'     => '-- 指定なし --',
-			'selected' => $selected			// 選択中かどうか
-		);
-		$this->tmpl->addVars('theme_list', $row);
-		$this->tmpl->parseTemplate('theme_list', 'a');
-					
-		if (is_dir($themeDir)){
-			$dir = dir($themeDir);
-			while (($file = $dir->read()) !== false){
-				$filePath = $themeDir . '/' . $file;
-				// ディレクトリかどうかチェック
-				if (strncmp($file, '.', 1) != 0 && $file != '..' && is_dir($filePath) &&
-					strncmp($file, '_', 1) != 0){	// 「_」で始まる名前のディレクトリは読み込まない
-
-					$selected = '';
-					if ($file == $this->defaultTheme) $selected = 'selected';
-					
-					$row = array(
-						'value'    => $this->convertToDispString($file),			// テーマID
-						'name'     => $this->convertToDispString($file),
-						'selected' => $selected			// 選択中かどうか
-					);
-					$this->tmpl->addVars('theme_list', $row);
-					$this->tmpl->parseTemplate('theme_list', 'a');
-				}
-			}
-			$dir->close();
-		}
-	}
 	/**
 	 * システム画面用テンプレート一覧を作成
 	 *
@@ -762,15 +556,22 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 	 */
 	function sysTemplateLoop($index, $fetchedRow, $param)
 	{
-		$selected = '';
-		if ($fetchedRow['tm_id'] == $this->systemTemplate){
-			$selected = 'selected';
-		}
+		$templateId = $fetchedRow['tm_id'];
+		
+
 		$name = $fetchedRow['tm_name'];
-		if ($fetchedRow['tm_id'] == self::DEFAULT_SYSTEM_TEMPLATE_ID) $name = '[デフォルト]';
+		if ($templateId == self::DEFAULT_SYSTEM_TEMPLATE_ID){
+			$name = '[デフォルト]';
+		} else if (strStartsWith($templateId, '_')){			// 「_」で始まるテンプレートは表示しない
+			return true;
+		}
+		
+		// 選択状態
+		$selected = '';
+		if ($templateId == $this->systemTemplate) $selected = 'selected';
 		
 		$row = array(
-			'value'    => $this->convertToDispString($fetchedRow['tm_id']),			// テンプレートID
+			'value'    => $this->convertToDispString($templateId),			// テンプレートID
 			'name'     => $this->convertToDispString($name),			// テンプレート名名
 			'selected' => $selected														// 選択中かどうか
 		);
@@ -802,28 +603,6 @@ class admin_mainConfigsysWidgetContainer extends admin_mainConfigsystemBaseWidge
 			$this->tmpl->parseTemplate('jquery_version_list', 'a');
 		}
 	}
-	/**
-	 * WYSIWYGエディター選択メニュー作成
-	 *
-	 * @return 							なし
-	 */
-	function createWysiwygMenu()
-	{
-		foreach ($this->wysiwygMenuData as $key => $value){
-			$name = $value;
-			
-			$selected = '';
-			if ($key == $this->wysiwygEditor) $selected = 'selected';
-			
-			$row = array(
-				'value'    => $this->convertToDispString($key),
-				'name'     => $this->convertToDispString($name),
-				'selected' => $selected			// 選択中かどうか
-			);
-			$this->tmpl->addVars('wysiwyg_editor_list', $row);
-			$this->tmpl->parseTemplate('wysiwyg_editor_list', 'a');
-		}
-	}
 	/**
 	 * アクセスポイントが有効かどうか
 	 *
