@@ -117,9 +117,6 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 		$titles = array(self::BREADCRUMB_TITLE);
 		
 		switch ($task){
-			case 'pagedef_mobile':		// 携帯用設定画面のとき
-				$titles[] = self::BREADCRUMB_TITLE_MOBILE;
-				break;
 			case 'pagedef_smartphone':		// スマートフォン用設定画面のとき
 				$titles[] = self::BREADCRUMB_TITLE_SMARTPHONE;
 				break;
@@ -199,9 +196,6 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 		$layoutMode = $request->trimValueOf('layoutmode');// テンプレートモード(空=デザインテンプレート,plain=デザインなしテンプレート)
 		if (empty($this->pageId)){
 			switch ($task){
-				case 'pagedef_mobile':		// 携帯用設定画面のとき
-					$this->pageId = $this->gEnv->getDefaultMobilePageId();				// 携帯用デフォルト値取得
-					break;
 				case 'pagedef_smartphone':		// スマートフォン用設定画面のとき
 					$this->pageId = $this->gEnv->getDefaultSmartphonePageId();				// スマートフォン用デフォルト値取得
 					break;
@@ -214,14 +208,6 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 		
 		// デフォルトテンプレート取得
 		switch ($task){
-			case 'pagedef_mobile':	// 携帯用設定画面のとき
-				$this->templateId = $this->gSystem->defaultMobileTemplateId();
-				$deviceType = 1;		// デバイスタイプ(携帯)
-				$taskStr = 'pagedef_mobile';
-				$previewWidth = '600px';
-				$this->tmpl->addVar("_widget", "preview_option_class", 'class="layout_top_border layout_side_border"');		// プレビューエリアにトップとサイドのボーダーラインを付加
-				$this->tmpl->addVar("_widget", "template_normal_disabled", 'disabled');
-				break;
 			case 'pagedef_smartphone':		// スマートフォン用設定画面
 				$this->templateId = $this->gSystem->defaultSmartphoneTemplateId();
 				$deviceType = 2;		// デバイスタイプ(スマートフォン)
@@ -244,9 +230,6 @@ class admin_mainPagedefWidgetContainer extends BaseAdminWidgetContainer
 			$templateId = $request->trimValueOf('sel_template');		// テンプレートID
 			if (!empty($templateId)){
 				switch ($task){
-					case 'pagedef_mobile':		// 携帯用設定画面のとき
-						$this->gSystem->changeDefaultMobileTemplate($templateId);
-						break;
 					case 'pagedef_smartphone':		// スマートフォン用設定画面のとき
 						$this->gSystem->changeDefaultSmartphoneTemplate($templateId);
 						break;
