@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2016 Magic3 Project.
+ * @copyright  Copyright 2006-2018 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -27,10 +27,6 @@ class admin_mainServeradminBaseWidgetContainer extends admin_mainBaseWidgetConta
 	const BREADCRUMB_TITLE	= 'サーバ管理';		// パンくずリストトップタイトル
 	const JOB_OPTION_FILE_DIR	= 'file';		// ジョブ用ファイル格納ディレクトリ
 	// 画面
-	const TASK_SERVERINFO		= 'serverinfo';			// サーバ情報
-	const TASK_SITELIST			= 'sitelist';			// サイト一覧
-	const TASK_SITELIST_DETAIL	= 'sitelist_detail';	// サイト詳細
-	const TASK_SERVERTOOL		= 'servertool';			// サーバ管理ツール
 	const DEFAULT_TASK			= 'serverinfo';			// デフォルトの画面
 	// ジョブタイプ
 	const JOB_TYPE_CREATE_SITE				= 'CREATESITE';				// サイト作成ジョブ
