@@ -214,7 +214,6 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 								$task == self::TASK_TEMPGENERATECSS_DETAIL){	// テンプレートCSS生成(詳細)
 						$task = self::TASK_TEMPGENERATECSS;
 					} else if ($task == 'pagedef_detail' ||		// ページ定義詳細
-								$task == 'pagedef_mobile' ||	// 携帯用ページ定義
 								$task == 'pagedef_smartphone'){		// スマートフォン用ページ定義
 						$task = 'pagedef';
 					} else if ($task == 'edittable' ||		// テーブルデータ編集一覧
@@ -339,7 +338,6 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 						case 'install':			// インストール
 						case 'sitelist':		// サイト一覧
 						case 'createconfig':	// 設定ファイル作成
-						case 'test':			// テスト用画面
 							$this->gLaunch->goSubWidget($task);
 							return false;
 						case 'logout':		// ログアウト処理
@@ -357,6 +355,8 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 									// テストタスクの場合はクラスロード用ディレクトリ追加
 									switch ($taskStart){
 									case self::TASK_TEST:
+										if ($task == 'test') return false;			// 「task」の場合は空画面表示
+										
 										$path = $this->gEnv->getCurrentWidgetContainerPath() . '/' . self::TASK_TEST;
 										$this->gLaunch->addLoadPath($path);
 										break;
@@ -507,8 +507,6 @@ class admin_mainWidgetContainer extends admin_mainBaseWidgetContainer
 		// PC用サイト、携帯用サイト、スマートフォン用サイトを判断
 		if ($this->gEnv->getIsPcSite()){
 			return '';
-		} else if ($this->gEnv->getIsMobileSite()){
-			return 'mobile';
 		} else if ($this->gEnv->getIsSmartphoneSite()){
 			return 'smartphone';
 		} else {
