@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: bbs_2ch_mainDb.php 4019 2011-03-06 11:37:15Z fishbone $
+ * @version    SVN: $Id: bbs_2ch_mainDb.php 4026 2011-03-10 07:40:49Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -144,6 +144,35 @@ class bbs_2ch_mainDb extends BaseDb
 		}
 		$this->selectLoop($queryStr, array($boardId), $callback, null);
 	}
+	/**
+	 * スレッド件名を検索キーワードで取得
+	 *
+	 * @param function	$callback		コールバック関数
+	 * @param string    $boardId		掲示板ID
+	 * @param int       $limit			取得数(-1=すべて取得)
+	 * @param string    $keyword		検索キーワード
+	 * @return 			なし
+	 */
+	function getThreadByKeyword($callback, $boardId, $limit, $keyword)
+	{
+		$queryStr  = 'SELECT th_id,th_subject,th_message_count FROM bbs_2ch_thread_message LEFT JOIN bbs_2ch_thread ON te_board_id = th_board_id AND te_thread_id = th_id AND th_deleted = false ';
+		$queryStr .=   'WHERE te_board_id = ? ';
+		$queryStr .=     'AND te_deleted = false ';		// 削除されていない
+		
+		// 「'"\」文字をエスケープ
+		$keyword = addslashes($keyword);
+		$queryStr .=     'AND (te_user_name LIKE \'%' . $keyword . '%\' ';
+		$queryStr .=     'OR te_email LIKE \'%' . $keyword . '%\' ';
+		$queryStr .=     'OR te_message LIKE \'%' . $keyword . '%\') ';
+			
+		$queryStr .=   'GROUP BY th_id ';
+		if ($limit == -1){
+			$queryStr .=  'ORDER BY th_dt DESC';
+		} else {
+			$queryStr .=  'ORDER BY th_dt DESC limit ' . intval($limit);
+		}
+		$this->selectLoop($queryStr, array($boardId), $callback, null);
+	}
 	/**
 	 * スレッドメッセージを取得
 	 *
@@ -384,7 +413,7 @@ class bbs_2ch_mainDb extends BaseDb
 		$queryStr .=   'SET te_deleted = true, ';	// 削除
 		$queryStr .=     'te_update_user_id = ?, ';
 		$queryStr .=     'te_update_dt = ? ';
-		$queryStr .=   'WHERE te_serial in (' . implode($serial, ',') . ') ';
+		$queryStr .=   'WHERE te_serial in (' . implode(',', $serial) . ') ';
 		$this->execStatement($queryStr, array($userId, $now));
 		
 		// スレッド削除
