@@ -232,8 +232,8 @@ class admin_blog_mainCommentWidgetContainer extends admin_blog_mainBaseWidgetCon
 		$this->tmpl->addVar("_widget", "search_keyword", $search_keyword);	// 検索キーワード
 
 		// 非表示項目を設定
-		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
-		$this->tmpl->addVar("_widget", "entry_list", implode($this->entryArray, ','));// 表示項目の記事IDを設定
+		$this->tmpl->addVar("_widget", "serial_list", implode(',', $this->serialArray));// 表示項目のシリアル番号を設定
+		$this->tmpl->addVar("_widget", "entry_list", implode(',', $this->entryArray));// 表示項目の記事IDを設定
 		$this->tmpl->addVar("_widget", "page", $pageNo);	// ページ番号
 		$this->tmpl->addVar("_widget", "list_count", $maxListCount);	// 一覧表示項目数
 	}
