@@ -211,7 +211,7 @@ class admin_calendarEventWidgetContainer extends admin_calendarBaseWidgetContain
 		$this->tmpl->addVar("_widget", "search_keyword", $search_keyword);	// 検索キーワード
 
 		// 非表示項目を設定
-		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
+		$this->tmpl->addVar("_widget", "serial_list", implode(',', $this->serialArray));// 表示項目のシリアル番号を設定
 		$this->tmpl->addVar("_widget", "page", $pageNo);	// ページ番号
 	}
 	/**
