@@ -167,7 +167,7 @@ class s_photoDb extends BaseDb
 		$queryStr .=   'SET lu_deleted = true, ';	// 削除
 		$queryStr .=     'lu_update_user_id = ?, ';
 		$queryStr .=     'lu_update_dt = ? ';
-		$queryStr .=   'WHERE lu_serial in (' . implode($serial, ',') . ') ';
+		$queryStr .=   'WHERE lu_serial in (' . implode(',', $serial) . ') ';
 		$this->execStatement($queryStr, array($userId, $now));
 		
 		// トランザクション確定
